from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.check_target import CheckTarget
from ..models.check_time_scale import CheckTimeScale
from ..models.check_type import CheckType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.field_model import FieldModel
    from ..models.rule_parameters_model import RuleParametersModel


T = TypeVar("T", bound="CheckConfigurationModel")


@_attrs_define
class CheckConfigurationModel:
    """Model containing fundamental configuration of a single data quality check.

    Attributes:
        connection_name (Union[Unset, str]): Connection name.
        schema_name (Union[Unset, str]): Schema name.
        table_name (Union[Unset, str]): Table name.
        column_name (Union[Unset, str]): Column name, if the check is set up on a column.
        check_target (Union[Unset, CheckTarget]):
        check_type (Union[Unset, CheckType]):
        check_time_scale (Union[Unset, CheckTimeScale]):
        category_name (Union[Unset, str]): Category to which this check belongs.
        check_name (Union[Unset, str]): Check name that is used in YAML file.
        sensor_parameters (Union[Unset, List['FieldModel']]): List of fields for editing the sensor parameters.
        table_level_filter (Union[Unset, str]): SQL WHERE clause added to the sensor query for every check on this
            table.
        sensor_level_filter (Union[Unset, str]): SQL WHERE clause added to the sensor query for this check.
        warning (Union[Unset, RuleParametersModel]): Model that returns the form definition and the form data to edit
            parameters (thresholds) for a rule at a single severity level (low, medium, high).
        error (Union[Unset, RuleParametersModel]): Model that returns the form definition and the form data to edit
            parameters (thresholds) for a rule at a single severity level (low, medium, high).
        fatal (Union[Unset, RuleParametersModel]): Model that returns the form definition and the form data to edit
            parameters (thresholds) for a rule at a single severity level (low, medium, high).
        disabled (Union[Unset, bool]): Whether the check has been disabled.
        configured (Union[Unset, bool]): Whether the check is configured (not null).
    """

    connection_name: Union[Unset, str] = UNSET
    schema_name: Union[Unset, str] = UNSET
    table_name: Union[Unset, str] = UNSET
    column_name: Union[Unset, str] = UNSET
    check_target: Union[Unset, CheckTarget] = UNSET
    check_type: Union[Unset, CheckType] = UNSET
    check_time_scale: Union[Unset, CheckTimeScale] = UNSET
    category_name: Union[Unset, str] = UNSET
    check_name: Union[Unset, str] = UNSET
    sensor_parameters: Union[Unset, List["FieldModel"]] = UNSET
    table_level_filter: Union[Unset, str] = UNSET
    sensor_level_filter: Union[Unset, str] = UNSET
    warning: Union[Unset, "RuleParametersModel"] = UNSET
    error: Union[Unset, "RuleParametersModel"] = UNSET
    fatal: Union[Unset, "RuleParametersModel"] = UNSET
    disabled: Union[Unset, bool] = UNSET
    configured: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        connection_name = self.connection_name
        schema_name = self.schema_name
        table_name = self.table_name
        column_name = self.column_name
        check_target: Union[Unset, str] = UNSET
        if not isinstance(self.check_target, Unset):
            check_target = self.check_target.value

        check_type: Union[Unset, str] = UNSET
        if not isinstance(self.check_type, Unset):
            check_type = self.check_type.value

        check_time_scale: Union[Unset, str] = UNSET
        if not isinstance(self.check_time_scale, Unset):
            check_time_scale = self.check_time_scale.value

        category_name = self.category_name
        check_name = self.check_name
        sensor_parameters: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.sensor_parameters, Unset):
            sensor_parameters = []
            for sensor_parameters_item_data in self.sensor_parameters:
                sensor_parameters_item = sensor_parameters_item_data.to_dict()

                sensor_parameters.append(sensor_parameters_item)

        table_level_filter = self.table_level_filter
        sensor_level_filter = self.sensor_level_filter
        warning: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.warning, Unset):
            warning = self.warning.to_dict()

        error: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.error, Unset):
            error = self.error.to_dict()

        fatal: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.fatal, Unset):
            fatal = self.fatal.to_dict()

        disabled = self.disabled
        configured = self.configured

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if connection_name is not UNSET:
            field_dict["connection_name"] = connection_name
        if schema_name is not UNSET:
            field_dict["schema_name"] = schema_name
        if table_name is not UNSET:
            field_dict["table_name"] = table_name
        if column_name is not UNSET:
            field_dict["column_name"] = column_name
        if check_target is not UNSET:
            field_dict["check_target"] = check_target
        if check_type is not UNSET:
            field_dict["check_type"] = check_type
        if check_time_scale is not UNSET:
            field_dict["check_time_scale"] = check_time_scale
        if category_name is not UNSET:
            field_dict["category_name"] = category_name
        if check_name is not UNSET:
            field_dict["check_name"] = check_name
        if sensor_parameters is not UNSET:
            field_dict["sensor_parameters"] = sensor_parameters
        if table_level_filter is not UNSET:
            field_dict["table_level_filter"] = table_level_filter
        if sensor_level_filter is not UNSET:
            field_dict["sensor_level_filter"] = sensor_level_filter
        if warning is not UNSET:
            field_dict["warning"] = warning
        if error is not UNSET:
            field_dict["error"] = error
        if fatal is not UNSET:
            field_dict["fatal"] = fatal
        if disabled is not UNSET:
            field_dict["disabled"] = disabled
        if configured is not UNSET:
            field_dict["configured"] = configured

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.field_model import FieldModel
        from ..models.rule_parameters_model import RuleParametersModel

        d = src_dict.copy()
        connection_name = d.pop("connection_name", UNSET)

        schema_name = d.pop("schema_name", UNSET)

        table_name = d.pop("table_name", UNSET)

        column_name = d.pop("column_name", UNSET)

        _check_target = d.pop("check_target", UNSET)
        check_target: Union[Unset, CheckTarget]
        if isinstance(_check_target, Unset):
            check_target = UNSET
        else:
            check_target = CheckTarget(_check_target)

        _check_type = d.pop("check_type", UNSET)
        check_type: Union[Unset, CheckType]
        if isinstance(_check_type, Unset):
            check_type = UNSET
        else:
            check_type = CheckType(_check_type)

        _check_time_scale = d.pop("check_time_scale", UNSET)
        check_time_scale: Union[Unset, CheckTimeScale]
        if isinstance(_check_time_scale, Unset):
            check_time_scale = UNSET
        else:
            check_time_scale = CheckTimeScale(_check_time_scale)

        category_name = d.pop("category_name", UNSET)

        check_name = d.pop("check_name", UNSET)

        sensor_parameters = []
        _sensor_parameters = d.pop("sensor_parameters", UNSET)
        for sensor_parameters_item_data in _sensor_parameters or []:
            sensor_parameters_item = FieldModel.from_dict(sensor_parameters_item_data)

            sensor_parameters.append(sensor_parameters_item)

        table_level_filter = d.pop("table_level_filter", UNSET)

        sensor_level_filter = d.pop("sensor_level_filter", UNSET)

        _warning = d.pop("warning", UNSET)
        warning: Union[Unset, RuleParametersModel]
        if isinstance(_warning, Unset):
            warning = UNSET
        else:
            warning = RuleParametersModel.from_dict(_warning)

        _error = d.pop("error", UNSET)
        error: Union[Unset, RuleParametersModel]
        if isinstance(_error, Unset):
            error = UNSET
        else:
            error = RuleParametersModel.from_dict(_error)

        _fatal = d.pop("fatal", UNSET)
        fatal: Union[Unset, RuleParametersModel]
        if isinstance(_fatal, Unset):
            fatal = UNSET
        else:
            fatal = RuleParametersModel.from_dict(_fatal)

        disabled = d.pop("disabled", UNSET)

        configured = d.pop("configured", UNSET)

        check_configuration_model = cls(
            connection_name=connection_name,
            schema_name=schema_name,
            table_name=table_name,
            column_name=column_name,
            check_target=check_target,
            check_type=check_type,
            check_time_scale=check_time_scale,
            category_name=category_name,
            check_name=check_name,
            sensor_parameters=sensor_parameters,
            table_level_filter=table_level_filter,
            sensor_level_filter=sensor_level_filter,
            warning=warning,
            error=error,
            fatal=fatal,
            disabled=disabled,
            configured=configured,
        )

        check_configuration_model.additional_properties = d
        return check_configuration_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.domain_connection_table_key import DomainConnectionTableKey
    from ..models.table_current_data_quality_status_model import (
        TableCurrentDataQualityStatusModel,
    )


T = TypeVar("T", bound="TableLineageFlowModel")


@_attrs_define
class TableLineageFlowModel:
    """Table lineage flow model that describes the data flow from one table to another table, and the data quality status
    of the source table.

        Attributes:
            source_table (Union[Unset, DomainConnectionTableKey]): Table key that identifies a table in the data quality
                cache or a data lineage cache.
            target_table (Union[Unset, DomainConnectionTableKey]): Table key that identifies a table in the data quality
                cache or a data lineage cache.
            source_table_quality_status (Union[Unset, TableCurrentDataQualityStatusModel]): The table's most recent data
                quality status. It is a summary of the results of the most recently executed data quality checks on the table.
                Verify the value of the highest_severity_level to see if there are any data quality issues on the table. The
                values of severity levels are: 0 - all data quality checks passed, 1 - a warning was detected, 2 - an error was
                detected, 3 - a fatal data quality issue was detected.
            target_table_quality_status (Union[Unset, TableCurrentDataQualityStatusModel]): The table's most recent data
                quality status. It is a summary of the results of the most recently executed data quality checks on the table.
                Verify the value of the highest_severity_level to see if there are any data quality issues on the table. The
                values of severity levels are: 0 - all data quality checks passed, 1 - a warning was detected, 2 - an error was
                detected, 3 - a fatal data quality issue was detected.
            upstream_combined_quality_status (Union[Unset, TableCurrentDataQualityStatusModel]): The table's most recent
                data quality status. It is a summary of the results of the most recently executed data quality checks on the
                table. Verify the value of the highest_severity_level to see if there are any data quality issues on the table.
                The values of severity levels are: 0 - all data quality checks passed, 1 - a warning was detected, 2 - an error
                was detected, 3 - a fatal data quality issue was detected.
            row_count (Union[Unset, int]): The row count of the source table.
    """

    source_table: Union[Unset, "DomainConnectionTableKey"] = UNSET
    target_table: Union[Unset, "DomainConnectionTableKey"] = UNSET
    source_table_quality_status: Union[Unset, "TableCurrentDataQualityStatusModel"] = (
        UNSET
    )
    target_table_quality_status: Union[Unset, "TableCurrentDataQualityStatusModel"] = (
        UNSET
    )
    upstream_combined_quality_status: Union[
        Unset, "TableCurrentDataQualityStatusModel"
    ] = UNSET
    row_count: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        source_table: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.source_table, Unset):
            source_table = self.source_table.to_dict()

        target_table: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.target_table, Unset):
            target_table = self.target_table.to_dict()

        source_table_quality_status: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.source_table_quality_status, Unset):
            source_table_quality_status = self.source_table_quality_status.to_dict()

        target_table_quality_status: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.target_table_quality_status, Unset):
            target_table_quality_status = self.target_table_quality_status.to_dict()

        upstream_combined_quality_status: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.upstream_combined_quality_status, Unset):
            upstream_combined_quality_status = (
                self.upstream_combined_quality_status.to_dict()
            )

        row_count = self.row_count

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if source_table is not UNSET:
            field_dict["source_table"] = source_table
        if target_table is not UNSET:
            field_dict["target_table"] = target_table
        if source_table_quality_status is not UNSET:
            field_dict["source_table_quality_status"] = source_table_quality_status
        if target_table_quality_status is not UNSET:
            field_dict["target_table_quality_status"] = target_table_quality_status
        if upstream_combined_quality_status is not UNSET:
            field_dict["upstream_combined_quality_status"] = (
                upstream_combined_quality_status
            )
        if row_count is not UNSET:
            field_dict["row_count"] = row_count

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.domain_connection_table_key import DomainConnectionTableKey
        from ..models.table_current_data_quality_status_model import (
            TableCurrentDataQualityStatusModel,
        )

        d = src_dict.copy()
        _source_table = d.pop("source_table", UNSET)
        source_table: Union[Unset, DomainConnectionTableKey]
        if isinstance(_source_table, Unset):
            source_table = UNSET
        else:
            source_table = DomainConnectionTableKey.from_dict(_source_table)

        _target_table = d.pop("target_table", UNSET)
        target_table: Union[Unset, DomainConnectionTableKey]
        if isinstance(_target_table, Unset):
            target_table = UNSET
        else:
            target_table = DomainConnectionTableKey.from_dict(_target_table)

        _source_table_quality_status = d.pop("source_table_quality_status", UNSET)
        source_table_quality_status: Union[Unset, TableCurrentDataQualityStatusModel]
        if isinstance(_source_table_quality_status, Unset):
            source_table_quality_status = UNSET
        else:
            source_table_quality_status = TableCurrentDataQualityStatusModel.from_dict(
                _source_table_quality_status
            )

        _target_table_quality_status = d.pop("target_table_quality_status", UNSET)
        target_table_quality_status: Union[Unset, TableCurrentDataQualityStatusModel]
        if isinstance(_target_table_quality_status, Unset):
            target_table_quality_status = UNSET
        else:
            target_table_quality_status = TableCurrentDataQualityStatusModel.from_dict(
                _target_table_quality_status
            )

        _upstream_combined_quality_status = d.pop(
            "upstream_combined_quality_status", UNSET
        )
        upstream_combined_quality_status: Union[
            Unset, TableCurrentDataQualityStatusModel
        ]
        if isinstance(_upstream_combined_quality_status, Unset):
            upstream_combined_quality_status = UNSET
        else:
            upstream_combined_quality_status = (
                TableCurrentDataQualityStatusModel.from_dict(
                    _upstream_combined_quality_status
                )
            )

        row_count = d.pop("row_count", UNSET)

        table_lineage_flow_model = cls(
            source_table=source_table,
            target_table=target_table,
            source_table_quality_status=source_table_quality_status,
            target_table_quality_status=target_table_quality_status,
            upstream_combined_quality_status=upstream_combined_quality_status,
            row_count=row_count,
        )

        table_lineage_flow_model.additional_properties = d
        return table_lineage_flow_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.incident_notification_target_spec import (
        IncidentNotificationTargetSpec,
    )
    from ..models.notification_filter_spec import NotificationFilterSpec


T = TypeVar("T", bound="FilteredNotificationSpec")


@_attrs_define
class FilteredNotificationSpec:
    """
    Attributes:
        filter_ (Union[Unset, NotificationFilterSpec]):
        target (Union[Unset, IncidentNotificationTargetSpec]):
        priority (Union[Unset, int]): The priority of the notification. Notifications are sent to the first notification
            targets that matches the filters when processAdditionalFilters is not set.
        process_additional_filters (Union[Unset, bool]): Flag to break sending next notifications. Setting to true
            allows to send next notification from the list in priority order that matches the filter.
        disabled (Union[Unset, bool]): Flag to turn off the notification filter.
        message (Union[Unset, str]): Message with the details of the filtered notification such as purpose explanation,
            SLA note, etc.
        do_not_create_incidents (Union[Unset, bool]): Flag to remove incident that match the filters.
    """

    filter_: Union[Unset, "NotificationFilterSpec"] = UNSET
    target: Union[Unset, "IncidentNotificationTargetSpec"] = UNSET
    priority: Union[Unset, int] = UNSET
    process_additional_filters: Union[Unset, bool] = UNSET
    disabled: Union[Unset, bool] = UNSET
    message: Union[Unset, str] = UNSET
    do_not_create_incidents: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        filter_: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.filter_, Unset):
            filter_ = self.filter_.to_dict()

        target: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.target, Unset):
            target = self.target.to_dict()

        priority = self.priority
        process_additional_filters = self.process_additional_filters
        disabled = self.disabled
        message = self.message
        do_not_create_incidents = self.do_not_create_incidents

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if filter_ is not UNSET:
            field_dict["filter"] = filter_
        if target is not UNSET:
            field_dict["target"] = target
        if priority is not UNSET:
            field_dict["priority"] = priority
        if process_additional_filters is not UNSET:
            field_dict["process_additional_filters"] = process_additional_filters
        if disabled is not UNSET:
            field_dict["disabled"] = disabled
        if message is not UNSET:
            field_dict["message"] = message
        if do_not_create_incidents is not UNSET:
            field_dict["do_not_create_incidents"] = do_not_create_incidents

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.incident_notification_target_spec import (
            IncidentNotificationTargetSpec,
        )
        from ..models.notification_filter_spec import NotificationFilterSpec

        d = src_dict.copy()
        _filter_ = d.pop("filter", UNSET)
        filter_: Union[Unset, NotificationFilterSpec]
        if isinstance(_filter_, Unset):
            filter_ = UNSET
        else:
            filter_ = NotificationFilterSpec.from_dict(_filter_)

        _target = d.pop("target", UNSET)
        target: Union[Unset, IncidentNotificationTargetSpec]
        if isinstance(_target, Unset):
            target = UNSET
        else:
            target = IncidentNotificationTargetSpec.from_dict(_target)

        priority = d.pop("priority", UNSET)

        process_additional_filters = d.pop("process_additional_filters", UNSET)

        disabled = d.pop("disabled", UNSET)

        message = d.pop("message", UNSET)

        do_not_create_incidents = d.pop("do_not_create_incidents", UNSET)

        filtered_notification_spec = cls(
            filter_=filter_,
            target=target,
            priority=priority,
            process_additional_filters=process_additional_filters,
            disabled=disabled,
            message=message,
            do_not_create_incidents=do_not_create_incidents,
        )

        filtered_notification_spec.additional_properties = d
        return filtered_notification_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.change_percent_30_days_rule_10_parameters_spec import (
        ChangePercent30DaysRule10ParametersSpec,
    )
    from ..models.change_percent_30_days_rule_20_parameters_spec import (
        ChangePercent30DaysRule20ParametersSpec,
    )
    from ..models.change_percent_30_days_rule_50_parameters_spec import (
        ChangePercent30DaysRule50ParametersSpec,
    )
    from ..models.column_uniqueness_distinct_count_sensor_parameters_spec import (
        ColumnUniquenessDistinctCountSensorParametersSpec,
    )
    from ..models.comment_spec import CommentSpec
    from ..models.cron_schedule_spec import CronScheduleSpec


T = TypeVar("T", bound="ColumnDistinctCountChange30DaysCheckSpec")


@_attrs_define
class ColumnDistinctCountChange30DaysCheckSpec:
    """
    Attributes:
        schedule_override (Union[Unset, CronScheduleSpec]):
        comments (Union[Unset, List['CommentSpec']]): Comments for change tracking. Please put comments in this
            collection because YAML comments may be removed when the YAML file is modified by the tool (serialization and
            deserialization will remove non tracked comments).
        disabled (Union[Unset, bool]): Disables the data quality check. Only enabled data quality checks and monitorings
            are executed. The check should be disabled if it should not work, but the configuration of the sensor and rules
            should be preserved in the configuration.
        exclude_from_kpi (Union[Unset, bool]): Data quality check results (alerts) are included in the data quality KPI
            calculation by default. Set this field to true in order to exclude this data quality check from the data quality
            KPI calculation.
        include_in_sla (Union[Unset, bool]): Marks the data quality check as part of a data quality SLA (Data Contract).
            The data quality SLA is a set of critical data quality checks that must always pass and are considered as a Data
            Contract for the dataset.
        quality_dimension (Union[Unset, str]): Configures a custom data quality dimension name that is different than
            the built-in dimensions (Timeliness, Validity, etc.).
        display_name (Union[Unset, str]): Data quality check display name that can be assigned to the check, otherwise
            the check_display_name stored in the parquet result files is the check_name.
        data_grouping (Union[Unset, str]): Data grouping configuration name that should be applied to this data quality
            check. The data grouping is used to group the check's result by a GROUP BY clause in SQL, evaluating the data
            quality check for each group of rows. Use the name of one of data grouping configurations defined on the parent
            table.
        always_collect_error_samples (Union[Unset, bool]): Forces collecting error samples for this check whenever it
            fails, even if it is a monitoring check that is run by a scheduler, and running an additional query to collect
            error samples will impose additional load on the data source.
        do_not_schedule (Union[Unset, bool]): Disables running this check by a DQOps CRON scheduler. When a check is
            disabled from scheduling, it can be only triggered from the user interface or by submitting "run checks" job.
        parameters (Union[Unset, ColumnUniquenessDistinctCountSensorParametersSpec]):
        warning (Union[Unset, ChangePercent30DaysRule10ParametersSpec]):
        error (Union[Unset, ChangePercent30DaysRule20ParametersSpec]):
        fatal (Union[Unset, ChangePercent30DaysRule50ParametersSpec]):
    """

    schedule_override: Union[Unset, "CronScheduleSpec"] = UNSET
    comments: Union[Unset, List["CommentSpec"]] = UNSET
    disabled: Union[Unset, bool] = UNSET
    exclude_from_kpi: Union[Unset, bool] = UNSET
    include_in_sla: Union[Unset, bool] = UNSET
    quality_dimension: Union[Unset, str] = UNSET
    display_name: Union[Unset, str] = UNSET
    data_grouping: Union[Unset, str] = UNSET
    always_collect_error_samples: Union[Unset, bool] = UNSET
    do_not_schedule: Union[Unset, bool] = UNSET
    parameters: Union[Unset, "ColumnUniquenessDistinctCountSensorParametersSpec"] = (
        UNSET
    )
    warning: Union[Unset, "ChangePercent30DaysRule10ParametersSpec"] = UNSET
    error: Union[Unset, "ChangePercent30DaysRule20ParametersSpec"] = UNSET
    fatal: Union[Unset, "ChangePercent30DaysRule50ParametersSpec"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        schedule_override: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.schedule_override, Unset):
            schedule_override = self.schedule_override.to_dict()

        comments: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.comments, Unset):
            comments = []
            for comments_item_data in self.comments:
                comments_item = comments_item_data.to_dict()

                comments.append(comments_item)

        disabled = self.disabled
        exclude_from_kpi = self.exclude_from_kpi
        include_in_sla = self.include_in_sla
        quality_dimension = self.quality_dimension
        display_name = self.display_name
        data_grouping = self.data_grouping
        always_collect_error_samples = self.always_collect_error_samples
        do_not_schedule = self.do_not_schedule
        parameters: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.parameters, Unset):
            parameters = self.parameters.to_dict()

        warning: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.warning, Unset):
            warning = self.warning.to_dict()

        error: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.error, Unset):
            error = self.error.to_dict()

        fatal: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.fatal, Unset):
            fatal = self.fatal.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if schedule_override is not UNSET:
            field_dict["schedule_override"] = schedule_override
        if comments is not UNSET:
            field_dict["comments"] = comments
        if disabled is not UNSET:
            field_dict["disabled"] = disabled
        if exclude_from_kpi is not UNSET:
            field_dict["exclude_from_kpi"] = exclude_from_kpi
        if include_in_sla is not UNSET:
            field_dict["include_in_sla"] = include_in_sla
        if quality_dimension is not UNSET:
            field_dict["quality_dimension"] = quality_dimension
        if display_name is not UNSET:
            field_dict["display_name"] = display_name
        if data_grouping is not UNSET:
            field_dict["data_grouping"] = data_grouping
        if always_collect_error_samples is not UNSET:
            field_dict["always_collect_error_samples"] = always_collect_error_samples
        if do_not_schedule is not UNSET:
            field_dict["do_not_schedule"] = do_not_schedule
        if parameters is not UNSET:
            field_dict["parameters"] = parameters
        if warning is not UNSET:
            field_dict["warning"] = warning
        if error is not UNSET:
            field_dict["error"] = error
        if fatal is not UNSET:
            field_dict["fatal"] = fatal

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.change_percent_30_days_rule_10_parameters_spec import (
            ChangePercent30DaysRule10ParametersSpec,
        )
        from ..models.change_percent_30_days_rule_20_parameters_spec import (
            ChangePercent30DaysRule20ParametersSpec,
        )
        from ..models.change_percent_30_days_rule_50_parameters_spec import (
            ChangePercent30DaysRule50ParametersSpec,
        )
        from ..models.column_uniqueness_distinct_count_sensor_parameters_spec import (
            ColumnUniquenessDistinctCountSensorParametersSpec,
        )
        from ..models.comment_spec import CommentSpec
        from ..models.cron_schedule_spec import CronScheduleSpec

        d = src_dict.copy()
        _schedule_override = d.pop("schedule_override", UNSET)
        schedule_override: Union[Unset, CronScheduleSpec]
        if isinstance(_schedule_override, Unset):
            schedule_override = UNSET
        else:
            schedule_override = CronScheduleSpec.from_dict(_schedule_override)

        comments = []
        _comments = d.pop("comments", UNSET)
        for comments_item_data in _comments or []:
            comments_item = CommentSpec.from_dict(comments_item_data)

            comments.append(comments_item)

        disabled = d.pop("disabled", UNSET)

        exclude_from_kpi = d.pop("exclude_from_kpi", UNSET)

        include_in_sla = d.pop("include_in_sla", UNSET)

        quality_dimension = d.pop("quality_dimension", UNSET)

        display_name = d.pop("display_name", UNSET)

        data_grouping = d.pop("data_grouping", UNSET)

        always_collect_error_samples = d.pop("always_collect_error_samples", UNSET)

        do_not_schedule = d.pop("do_not_schedule", UNSET)

        _parameters = d.pop("parameters", UNSET)
        parameters: Union[Unset, ColumnUniquenessDistinctCountSensorParametersSpec]
        if isinstance(_parameters, Unset):
            parameters = UNSET
        else:
            parameters = ColumnUniquenessDistinctCountSensorParametersSpec.from_dict(
                _parameters
            )

        _warning = d.pop("warning", UNSET)
        warning: Union[Unset, ChangePercent30DaysRule10ParametersSpec]
        if isinstance(_warning, Unset):
            warning = UNSET
        else:
            warning = ChangePercent30DaysRule10ParametersSpec.from_dict(_warning)

        _error = d.pop("error", UNSET)
        error: Union[Unset, ChangePercent30DaysRule20ParametersSpec]
        if isinstance(_error, Unset):
            error = UNSET
        else:
            error = ChangePercent30DaysRule20ParametersSpec.from_dict(_error)

        _fatal = d.pop("fatal", UNSET)
        fatal: Union[Unset, ChangePercent30DaysRule50ParametersSpec]
        if isinstance(_fatal, Unset):
            fatal = UNSET
        else:
            fatal = ChangePercent30DaysRule50ParametersSpec.from_dict(_fatal)

        column_distinct_count_change_30_days_check_spec = cls(
            schedule_override=schedule_override,
            comments=comments,
            disabled=disabled,
            exclude_from_kpi=exclude_from_kpi,
            include_in_sla=include_in_sla,
            quality_dimension=quality_dimension,
            display_name=display_name,
            data_grouping=data_grouping,
            always_collect_error_samples=always_collect_error_samples,
            do_not_schedule=do_not_schedule,
            parameters=parameters,
            warning=warning,
            error=error,
            fatal=fatal,
        )

        column_distinct_count_change_30_days_check_spec.additional_properties = d
        return column_distinct_count_change_30_days_check_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="TableAccuracyTotalRowCountMatchPercentSensorParametersSpec")


@_attrs_define
class TableAccuracyTotalRowCountMatchPercentSensorParametersSpec:
    """
    Attributes:
        filter_ (Union[Unset, str]): SQL WHERE clause added to the sensor query. Both the table level filter and a
            sensor query filter are added, separated by an AND operator.
        referenced_table (Union[Unset, str]): The name of the reference table. DQOps accepts the name in two forms: a
            fully qualified name including the schema name, for example landing_zone.customer_raw, or only a table name.
            When only a table name is used, DQOps assumes that the table is in the same schema as the analyzed table, and
            prefixes the name with the schema and optionally database name.
    """

    filter_: Union[Unset, str] = UNSET
    referenced_table: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        filter_ = self.filter_
        referenced_table = self.referenced_table

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if filter_ is not UNSET:
            field_dict["filter"] = filter_
        if referenced_table is not UNSET:
            field_dict["referenced_table"] = referenced_table

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        filter_ = d.pop("filter", UNSET)

        referenced_table = d.pop("referenced_table", UNSET)

        table_accuracy_total_row_count_match_percent_sensor_parameters_spec = cls(
            filter_=filter_,
            referenced_table=referenced_table,
        )

        table_accuracy_total_row_count_match_percent_sensor_parameters_spec.additional_properties = (
            d
        )
        return table_accuracy_total_row_count_match_percent_sensor_parameters_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.parameter_definition_spec import ParameterDefinitionSpec


T = TypeVar("T", bound="FieldModel")


@_attrs_define
class FieldModel:
    """Model of a single field that is used to edit a parameter value for a sensor or a rule. Describes the type of the
    field and the current value.

        Attributes:
            definition (Union[Unset, ParameterDefinitionSpec]): Defines a single field that is a sensor parameter or a rule
                parameter.
            optional (Union[Unset, bool]): Field value is optional and may be null, when false - the field is required and
                must be filled.
            string_value (Union[Unset, str]): Field value for a string field.
            boolean_value (Union[Unset, bool]): Field value for a boolean field.
            integer_value (Union[Unset, int]): Field value for an integer (32-bit) field.
            long_value (Union[Unset, int]): Field value for a long (64-bit) field.
            double_value (Union[Unset, float]): Field value for a double field.
            datetime_value (Union[Unset, datetime.datetime]): Field value for a date time field.
            column_name_value (Union[Unset, str]): Field value for a column name field.
            enum_value (Union[Unset, str]): Field value for an enum (choice) field.
            string_list_value (Union[Unset, List[str]]): Field value for an array (list) of strings.
            integer_list_value (Union[Unset, List[int]]): Field value for an array (list) of integers, using 64 bit
                integers.
            date_value (Union[Unset, datetime.date]): Field value for an date.
    """

    definition: Union[Unset, "ParameterDefinitionSpec"] = UNSET
    optional: Union[Unset, bool] = UNSET
    string_value: Union[Unset, str] = UNSET
    boolean_value: Union[Unset, bool] = UNSET
    integer_value: Union[Unset, int] = UNSET
    long_value: Union[Unset, int] = UNSET
    double_value: Union[Unset, float] = UNSET
    datetime_value: Union[Unset, datetime.datetime] = UNSET
    column_name_value: Union[Unset, str] = UNSET
    enum_value: Union[Unset, str] = UNSET
    string_list_value: Union[Unset, List[str]] = UNSET
    integer_list_value: Union[Unset, List[int]] = UNSET
    date_value: Union[Unset, datetime.date] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        definition: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.definition, Unset):
            definition = self.definition.to_dict()

        optional = self.optional
        string_value = self.string_value
        boolean_value = self.boolean_value
        integer_value = self.integer_value
        long_value = self.long_value
        double_value = self.double_value
        datetime_value: Union[Unset, str] = UNSET
        if not isinstance(self.datetime_value, Unset):
            datetime_value = self.datetime_value.isoformat()

        column_name_value = self.column_name_value
        enum_value = self.enum_value
        string_list_value: Union[Unset, List[str]] = UNSET
        if not isinstance(self.string_list_value, Unset):
            string_list_value = self.string_list_value

        integer_list_value: Union[Unset, List[int]] = UNSET
        if not isinstance(self.integer_list_value, Unset):
            integer_list_value = self.integer_list_value

        date_value: Union[Unset, str] = UNSET
        if not isinstance(self.date_value, Unset):
            date_value = self.date_value.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if definition is not UNSET:
            field_dict["definition"] = definition
        if optional is not UNSET:
            field_dict["optional"] = optional
        if string_value is not UNSET:
            field_dict["string_value"] = string_value
        if boolean_value is not UNSET:
            field_dict["boolean_value"] = boolean_value
        if integer_value is not UNSET:
            field_dict["integer_value"] = integer_value
        if long_value is not UNSET:
            field_dict["long_value"] = long_value
        if double_value is not UNSET:
            field_dict["double_value"] = double_value
        if datetime_value is not UNSET:
            field_dict["datetime_value"] = datetime_value
        if column_name_value is not UNSET:
            field_dict["column_name_value"] = column_name_value
        if enum_value is not UNSET:
            field_dict["enum_value"] = enum_value
        if string_list_value is not UNSET:
            field_dict["string_list_value"] = string_list_value
        if integer_list_value is not UNSET:
            field_dict["integer_list_value"] = integer_list_value
        if date_value is not UNSET:
            field_dict["date_value"] = date_value

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.parameter_definition_spec import ParameterDefinitionSpec

        d = src_dict.copy()
        _definition = d.pop("definition", UNSET)
        definition: Union[Unset, ParameterDefinitionSpec]
        if isinstance(_definition, Unset):
            definition = UNSET
        else:
            definition = ParameterDefinitionSpec.from_dict(_definition)

        optional = d.pop("optional", UNSET)

        string_value = d.pop("string_value", UNSET)

        boolean_value = d.pop("boolean_value", UNSET)

        integer_value = d.pop("integer_value", UNSET)

        long_value = d.pop("long_value", UNSET)

        double_value = d.pop("double_value", UNSET)

        _datetime_value = d.pop("datetime_value", UNSET)
        datetime_value: Union[Unset, datetime.datetime]
        if isinstance(_datetime_value, Unset):
            datetime_value = UNSET
        else:
            datetime_value = isoparse(_datetime_value)

        column_name_value = d.pop("column_name_value", UNSET)

        enum_value = d.pop("enum_value", UNSET)

        string_list_value = cast(List[str], d.pop("string_list_value", UNSET))

        integer_list_value = cast(List[int], d.pop("integer_list_value", UNSET))

        _date_value = d.pop("date_value", UNSET)
        date_value: Union[Unset, datetime.date]
        if isinstance(_date_value, Unset):
            date_value = UNSET
        else:
            date_value = isoparse(_date_value).date()

        field_model = cls(
            definition=definition,
            optional=optional,
            string_value=string_value,
            boolean_value=boolean_value,
            integer_value=integer_value,
            long_value=long_value,
            double_value=double_value,
            datetime_value=datetime_value,
            column_name_value=column_name_value,
            enum_value=enum_value,
            string_list_value=string_list_value,
            integer_list_value=integer_list_value,
            date_value=date_value,
        )

        field_model.additional_properties = d
        return field_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.authenticated_dashboard_model import AuthenticatedDashboardModel
from ...types import UNSET, Response, Unset


def _get_kwargs(
    folder1: str,
    folder2: str,
    folder3: str,
    folder4: str,
    folder5: str,
    dashboard_name: str,
    *,
    window_location_origin: Union[Unset, None, str] = UNSET,
) -> Dict[str, Any]:

    pass

    params: Dict[str, Any] = {}
    params["windowLocationOrigin"] = window_location_origin

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": "api/dashboards/{folder1}/{folder2}/{folder3}/{folder4}/{folder5}/{dashboardName}".format(
            folder1=folder1,
            folder2=folder2,
            folder3=folder3,
            folder4=folder4,
            folder5=folder5,
            dashboardName=dashboard_name,
        ),
        "params": params,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[AuthenticatedDashboardModel]:
    if response.status_code == HTTPStatus.OK:
        response_200 = AuthenticatedDashboardModel.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[AuthenticatedDashboardModel]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    folder1: str,
    folder2: str,
    folder3: str,
    folder4: str,
    folder5: str,
    dashboard_name: str,
    *,
    client: AuthenticatedClient,
    window_location_origin: Union[Unset, None, str] = UNSET,
) -> Response[AuthenticatedDashboardModel]:
    """getDashboardLevel5

     Returns a single dashboard in the tree of folders with a temporary authenticated url

    Args:
        folder1 (str):
        folder2 (str):
        folder3 (str):
        folder4 (str):
        folder5 (str):
        dashboard_name (str):
        window_location_origin (Union[Unset, None, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[AuthenticatedDashboardModel]
    """

    kwargs = _get_kwargs(
        folder1=folder1,
        folder2=folder2,
        folder3=folder3,
        folder4=folder4,
        folder5=folder5,
        dashboard_name=dashboard_name,
        window_location_origin=window_location_origin,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    folder1: str,
    folder2: str,
    folder3: str,
    folder4: str,
    folder5: str,
    dashboard_name: str,
    *,
    client: AuthenticatedClient,
    window_location_origin: Union[Unset, None, str] = UNSET,
) -> Optional[AuthenticatedDashboardModel]:
    """getDashboardLevel5

     Returns a single dashboard in the tree of folders with a temporary authenticated url

    Args:
        folder1 (str):
        folder2 (str):
        folder3 (str):
        folder4 (str):
        folder5 (str):
        dashboard_name (str):
        window_location_origin (Union[Unset, None, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        AuthenticatedDashboardModel
    """

    return sync_detailed(
        folder1=folder1,
        folder2=folder2,
        folder3=folder3,
        folder4=folder4,
        folder5=folder5,
        dashboard_name=dashboard_name,
        client=client,
        window_location_origin=window_location_origin,
    ).parsed


async def asyncio_detailed(
    folder1: str,
    folder2: str,
    folder3: str,
    folder4: str,
    folder5: str,
    dashboard_name: str,
    *,
    client: AuthenticatedClient,
    window_location_origin: Union[Unset, None, str] = UNSET,
) -> Response[AuthenticatedDashboardModel]:
    """getDashboardLevel5

     Returns a single dashboard in the tree of folders with a temporary authenticated url

    Args:
        folder1 (str):
        folder2 (str):
        folder3 (str):
        folder4 (str):
        folder5 (str):
        dashboard_name (str):
        window_location_origin (Union[Unset, None, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[AuthenticatedDashboardModel]
    """

    kwargs = _get_kwargs(
        folder1=folder1,
        folder2=folder2,
        folder3=folder3,
        folder4=folder4,
        folder5=folder5,
        dashboard_name=dashboard_name,
        window_location_origin=window_location_origin,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    folder1: str,
    folder2: str,
    folder3: str,
    folder4: str,
    folder5: str,
    dashboard_name: str,
    *,
    client: AuthenticatedClient,
    window_location_origin: Union[Unset, None, str] = UNSET,
) -> Optional[AuthenticatedDashboardModel]:
    """getDashboardLevel5

     Returns a single dashboard in the tree of folders with a temporary authenticated url

    Args:
        folder1 (str):
        folder2 (str):
        folder3 (str):
        folder4 (str):
        folder5 (str):
        dashboard_name (str):
        window_location_origin (Union[Unset, None, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        AuthenticatedDashboardModel
    """

    return (
        await asyncio_detailed(
            folder1=folder1,
            folder2=folder2,
            folder3=folder3,
            folder4=folder4,
            folder5=folder5,
            dashboard_name=dashboard_name,
            client=client,
            window_location_origin=window_location_origin,
        )
    ).parsed



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.check_type import CheckType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.error_entry_model import ErrorEntryModel


T = TypeVar("T", bound="ErrorsListModel")


@_attrs_define
class ErrorsListModel:
    """
    Attributes:
        check_name (Union[Unset, str]): Check name
        check_display_name (Union[Unset, str]): Check display name
        check_type (Union[Unset, CheckType]):
        check_hash (Union[Unset, int]): Check hash
        check_category (Union[Unset, str]): Check category name
        data_groups_names (Union[Unset, List[str]]): Data groups list
        data_group (Union[Unset, str]): Selected data group
        error_entries (Union[Unset, List['ErrorEntryModel']]): Error entries
    """

    check_name: Union[Unset, str] = UNSET
    check_display_name: Union[Unset, str] = UNSET
    check_type: Union[Unset, CheckType] = UNSET
    check_hash: Union[Unset, int] = UNSET
    check_category: Union[Unset, str] = UNSET
    data_groups_names: Union[Unset, List[str]] = UNSET
    data_group: Union[Unset, str] = UNSET
    error_entries: Union[Unset, List["ErrorEntryModel"]] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        check_name = self.check_name
        check_display_name = self.check_display_name
        check_type: Union[Unset, str] = UNSET
        if not isinstance(self.check_type, Unset):
            check_type = self.check_type.value

        check_hash = self.check_hash
        check_category = self.check_category
        data_groups_names: Union[Unset, List[str]] = UNSET
        if not isinstance(self.data_groups_names, Unset):
            data_groups_names = self.data_groups_names

        data_group = self.data_group
        error_entries: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.error_entries, Unset):
            error_entries = []
            for error_entries_item_data in self.error_entries:
                error_entries_item = error_entries_item_data.to_dict()

                error_entries.append(error_entries_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if check_name is not UNSET:
            field_dict["checkName"] = check_name
        if check_display_name is not UNSET:
            field_dict["checkDisplayName"] = check_display_name
        if check_type is not UNSET:
            field_dict["checkType"] = check_type
        if check_hash is not UNSET:
            field_dict["checkHash"] = check_hash
        if check_category is not UNSET:
            field_dict["checkCategory"] = check_category
        if data_groups_names is not UNSET:
            field_dict["dataGroupsNames"] = data_groups_names
        if data_group is not UNSET:
            field_dict["dataGroup"] = data_group
        if error_entries is not UNSET:
            field_dict["errorEntries"] = error_entries

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.error_entry_model import ErrorEntryModel

        d = src_dict.copy()
        check_name = d.pop("checkName", UNSET)

        check_display_name = d.pop("checkDisplayName", UNSET)

        _check_type = d.pop("checkType", UNSET)
        check_type: Union[Unset, CheckType]
        if isinstance(_check_type, Unset):
            check_type = UNSET
        else:
            check_type = CheckType(_check_type)

        check_hash = d.pop("checkHash", UNSET)

        check_category = d.pop("checkCategory", UNSET)

        data_groups_names = cast(List[str], d.pop("dataGroupsNames", UNSET))

        data_group = d.pop("dataGroup", UNSET)

        error_entries = []
        _error_entries = d.pop("errorEntries", UNSET)
        for error_entries_item_data in _error_entries or []:
            error_entries_item = ErrorEntryModel.from_dict(error_entries_item_data)

            error_entries.append(error_entries_item)

        errors_list_model = cls(
            check_name=check_name,
            check_display_name=check_display_name,
            check_type=check_type,
            check_hash=check_hash,
            check_category=check_category,
            data_groups_names=data_groups_names,
            data_group=data_group,
            error_entries=error_entries,
        )

        errors_list_model.additional_properties = d
        return errors_list_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class CompressionType(str, Enum):
    AUTO = "auto"
    GZIP = "gzip"
    LZ4 = "lz4"
    NONE = "none"
    SNAPPY = "snappy"
    ZSTD = "zstd"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.incident_status import IncidentStatus
from ..models.top_incident_grouping import TopIncidentGrouping
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.incident_severity_level_counts_model import (
        IncidentSeverityLevelCountsModel,
    )
    from ..models.top_incidents_model_top_incidents import TopIncidentsModelTopIncidents


T = TypeVar("T", bound="TopIncidentsModel")


@_attrs_define
class TopIncidentsModel:
    """
    Attributes:
        grouping (Union[Unset, TopIncidentGrouping]):
        status (Union[Unset, IncidentStatus]):
        top_incidents (Union[Unset, TopIncidentsModelTopIncidents]): Dictionary of the top incidents, grouped by the
            grouping such as the data quality dimension or a data quality check category. The incidents are sorted by the
            first seen descending (the most recent first).
        open_incident_severity_level_counts (Union[Unset, IncidentSeverityLevelCountsModel]):
        acknowledged_incident_severity_level_counts (Union[Unset, IncidentSeverityLevelCountsModel]):
    """

    grouping: Union[Unset, TopIncidentGrouping] = UNSET
    status: Union[Unset, IncidentStatus] = UNSET
    top_incidents: Union[Unset, "TopIncidentsModelTopIncidents"] = UNSET
    open_incident_severity_level_counts: Union[
        Unset, "IncidentSeverityLevelCountsModel"
    ] = UNSET
    acknowledged_incident_severity_level_counts: Union[
        Unset, "IncidentSeverityLevelCountsModel"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        grouping: Union[Unset, str] = UNSET
        if not isinstance(self.grouping, Unset):
            grouping = self.grouping.value

        status: Union[Unset, str] = UNSET
        if not isinstance(self.status, Unset):
            status = self.status.value

        top_incidents: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.top_incidents, Unset):
            top_incidents = self.top_incidents.to_dict()

        open_incident_severity_level_counts: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.open_incident_severity_level_counts, Unset):
            open_incident_severity_level_counts = (
                self.open_incident_severity_level_counts.to_dict()
            )

        acknowledged_incident_severity_level_counts: Union[Unset, Dict[str, Any]] = (
            UNSET
        )
        if not isinstance(self.acknowledged_incident_severity_level_counts, Unset):
            acknowledged_incident_severity_level_counts = (
                self.acknowledged_incident_severity_level_counts.to_dict()
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if grouping is not UNSET:
            field_dict["grouping"] = grouping
        if status is not UNSET:
            field_dict["status"] = status
        if top_incidents is not UNSET:
            field_dict["topIncidents"] = top_incidents
        if open_incident_severity_level_counts is not UNSET:
            field_dict["openIncidentSeverityLevelCounts"] = (
                open_incident_severity_level_counts
            )
        if acknowledged_incident_severity_level_counts is not UNSET:
            field_dict["acknowledgedIncidentSeverityLevelCounts"] = (
                acknowledged_incident_severity_level_counts
            )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.incident_severity_level_counts_model import (
            IncidentSeverityLevelCountsModel,
        )
        from ..models.top_incidents_model_top_incidents import (
            TopIncidentsModelTopIncidents,
        )

        d = src_dict.copy()
        _grouping = d.pop("grouping", UNSET)
        grouping: Union[Unset, TopIncidentGrouping]
        if isinstance(_grouping, Unset):
            grouping = UNSET
        else:
            grouping = TopIncidentGrouping(_grouping)

        _status = d.pop("status", UNSET)
        status: Union[Unset, IncidentStatus]
        if isinstance(_status, Unset):
            status = UNSET
        else:
            status = IncidentStatus(_status)

        _top_incidents = d.pop("topIncidents", UNSET)
        top_incidents: Union[Unset, TopIncidentsModelTopIncidents]
        if isinstance(_top_incidents, Unset):
            top_incidents = UNSET
        else:
            top_incidents = TopIncidentsModelTopIncidents.from_dict(_top_incidents)

        _open_incident_severity_level_counts = d.pop(
            "openIncidentSeverityLevelCounts", UNSET
        )
        open_incident_severity_level_counts: Union[
            Unset, IncidentSeverityLevelCountsModel
        ]
        if isinstance(_open_incident_severity_level_counts, Unset):
            open_incident_severity_level_counts = UNSET
        else:
            open_incident_severity_level_counts = (
                IncidentSeverityLevelCountsModel.from_dict(
                    _open_incident_severity_level_counts
                )
            )

        _acknowledged_incident_severity_level_counts = d.pop(
            "acknowledgedIncidentSeverityLevelCounts", UNSET
        )
        acknowledged_incident_severity_level_counts: Union[
            Unset, IncidentSeverityLevelCountsModel
        ]
        if isinstance(_acknowledged_incident_severity_level_counts, Unset):
            acknowledged_incident_severity_level_counts = UNSET
        else:
            acknowledged_incident_severity_level_counts = (
                IncidentSeverityLevelCountsModel.from_dict(
                    _acknowledged_incident_severity_level_counts
                )
            )

        top_incidents_model = cls(
            grouping=grouping,
            status=status,
            top_incidents=top_incidents,
            open_incident_severity_level_counts=open_incident_severity_level_counts,
            acknowledged_incident_severity_level_counts=acknowledged_incident_severity_level_counts,
        )

        top_incidents_model.additional_properties = d
        return top_incidents_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_anomaly_profiling_checks_spec_custom_checks import (
        ColumnAnomalyProfilingChecksSpecCustomChecks,
    )
    from ..models.column_max_anomaly_differencing_check_spec import (
        ColumnMaxAnomalyDifferencingCheckSpec,
    )
    from ..models.column_mean_anomaly_stationary_check_spec import (
        ColumnMeanAnomalyStationaryCheckSpec,
    )
    from ..models.column_mean_change_1_day_check_spec import (
        ColumnMeanChange1DayCheckSpec,
    )
    from ..models.column_mean_change_7_days_check_spec import (
        ColumnMeanChange7DaysCheckSpec,
    )
    from ..models.column_mean_change_30_days_check_spec import (
        ColumnMeanChange30DaysCheckSpec,
    )
    from ..models.column_mean_change_check_spec import ColumnMeanChangeCheckSpec
    from ..models.column_median_anomaly_stationary_check_spec import (
        ColumnMedianAnomalyStationaryCheckSpec,
    )
    from ..models.column_median_change_1_day_check_spec import (
        ColumnMedianChange1DayCheckSpec,
    )
    from ..models.column_median_change_7_days_check_spec import (
        ColumnMedianChange7DaysCheckSpec,
    )
    from ..models.column_median_change_30_days_check_spec import (
        ColumnMedianChange30DaysCheckSpec,
    )
    from ..models.column_median_change_check_spec import ColumnMedianChangeCheckSpec
    from ..models.column_min_anomaly_differencing_check_spec import (
        ColumnMinAnomalyDifferencingCheckSpec,
    )
    from ..models.column_sum_anomaly_differencing_check_spec import (
        ColumnSumAnomalyDifferencingCheckSpec,
    )
    from ..models.column_sum_change_1_day_check_spec import ColumnSumChange1DayCheckSpec
    from ..models.column_sum_change_7_days_check_spec import (
        ColumnSumChange7DaysCheckSpec,
    )
    from ..models.column_sum_change_30_days_check_spec import (
        ColumnSumChange30DaysCheckSpec,
    )
    from ..models.column_sum_change_check_spec import ColumnSumChangeCheckSpec


T = TypeVar("T", bound="ColumnAnomalyProfilingChecksSpec")


@_attrs_define
class ColumnAnomalyProfilingChecksSpec:
    """
    Attributes:
        custom_checks (Union[Unset, ColumnAnomalyProfilingChecksSpecCustomChecks]): Dictionary of additional custom
            checks within this category. The keys are check names defined in the definition section. The sensor parameters
            and rules should match the type of the configured sensor and rule for the custom check.
        profile_sum_anomaly (Union[Unset, ColumnSumAnomalyDifferencingCheckSpec]):
        profile_mean_anomaly (Union[Unset, ColumnMeanAnomalyStationaryCheckSpec]):
        profile_median_anomaly (Union[Unset, ColumnMedianAnomalyStationaryCheckSpec]):
        profile_min_anomaly (Union[Unset, ColumnMinAnomalyDifferencingCheckSpec]):
        profile_max_anomaly (Union[Unset, ColumnMaxAnomalyDifferencingCheckSpec]):
        profile_mean_change (Union[Unset, ColumnMeanChangeCheckSpec]):
        profile_median_change (Union[Unset, ColumnMedianChangeCheckSpec]):
        profile_sum_change (Union[Unset, ColumnSumChangeCheckSpec]):
        profile_mean_change_1_day (Union[Unset, ColumnMeanChange1DayCheckSpec]):
        profile_mean_change_7_days (Union[Unset, ColumnMeanChange7DaysCheckSpec]):
        profile_mean_change_30_days (Union[Unset, ColumnMeanChange30DaysCheckSpec]):
        profile_median_change_1_day (Union[Unset, ColumnMedianChange1DayCheckSpec]):
        profile_median_change_7_days (Union[Unset, ColumnMedianChange7DaysCheckSpec]):
        profile_median_change_30_days (Union[Unset, ColumnMedianChange30DaysCheckSpec]):
        profile_sum_change_1_day (Union[Unset, ColumnSumChange1DayCheckSpec]):
        profile_sum_change_7_days (Union[Unset, ColumnSumChange7DaysCheckSpec]):
        profile_sum_change_30_days (Union[Unset, ColumnSumChange30DaysCheckSpec]):
    """

    custom_checks: Union[Unset, "ColumnAnomalyProfilingChecksSpecCustomChecks"] = UNSET
    profile_sum_anomaly: Union[Unset, "ColumnSumAnomalyDifferencingCheckSpec"] = UNSET
    profile_mean_anomaly: Union[Unset, "ColumnMeanAnomalyStationaryCheckSpec"] = UNSET
    profile_median_anomaly: Union[Unset, "ColumnMedianAnomalyStationaryCheckSpec"] = (
        UNSET
    )
    profile_min_anomaly: Union[Unset, "ColumnMinAnomalyDifferencingCheckSpec"] = UNSET
    profile_max_anomaly: Union[Unset, "ColumnMaxAnomalyDifferencingCheckSpec"] = UNSET
    profile_mean_change: Union[Unset, "ColumnMeanChangeCheckSpec"] = UNSET
    profile_median_change: Union[Unset, "ColumnMedianChangeCheckSpec"] = UNSET
    profile_sum_change: Union[Unset, "ColumnSumChangeCheckSpec"] = UNSET
    profile_mean_change_1_day: Union[Unset, "ColumnMeanChange1DayCheckSpec"] = UNSET
    profile_mean_change_7_days: Union[Unset, "ColumnMeanChange7DaysCheckSpec"] = UNSET
    profile_mean_change_30_days: Union[Unset, "ColumnMeanChange30DaysCheckSpec"] = UNSET
    profile_median_change_1_day: Union[Unset, "ColumnMedianChange1DayCheckSpec"] = UNSET
    profile_median_change_7_days: Union[Unset, "ColumnMedianChange7DaysCheckSpec"] = (
        UNSET
    )
    profile_median_change_30_days: Union[Unset, "ColumnMedianChange30DaysCheckSpec"] = (
        UNSET
    )
    profile_sum_change_1_day: Union[Unset, "ColumnSumChange1DayCheckSpec"] = UNSET
    profile_sum_change_7_days: Union[Unset, "ColumnSumChange7DaysCheckSpec"] = UNSET
    profile_sum_change_30_days: Union[Unset, "ColumnSumChange30DaysCheckSpec"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_checks, Unset):
            custom_checks = self.custom_checks.to_dict()

        profile_sum_anomaly: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_sum_anomaly, Unset):
            profile_sum_anomaly = self.profile_sum_anomaly.to_dict()

        profile_mean_anomaly: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_mean_anomaly, Unset):
            profile_mean_anomaly = self.profile_mean_anomaly.to_dict()

        profile_median_anomaly: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_median_anomaly, Unset):
            profile_median_anomaly = self.profile_median_anomaly.to_dict()

        profile_min_anomaly: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_min_anomaly, Unset):
            profile_min_anomaly = self.profile_min_anomaly.to_dict()

        profile_max_anomaly: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_max_anomaly, Unset):
            profile_max_anomaly = self.profile_max_anomaly.to_dict()

        profile_mean_change: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_mean_change, Unset):
            profile_mean_change = self.profile_mean_change.to_dict()

        profile_median_change: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_median_change, Unset):
            profile_median_change = self.profile_median_change.to_dict()

        profile_sum_change: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_sum_change, Unset):
            profile_sum_change = self.profile_sum_change.to_dict()

        profile_mean_change_1_day: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_mean_change_1_day, Unset):
            profile_mean_change_1_day = self.profile_mean_change_1_day.to_dict()

        profile_mean_change_7_days: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_mean_change_7_days, Unset):
            profile_mean_change_7_days = self.profile_mean_change_7_days.to_dict()

        profile_mean_change_30_days: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_mean_change_30_days, Unset):
            profile_mean_change_30_days = self.profile_mean_change_30_days.to_dict()

        profile_median_change_1_day: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_median_change_1_day, Unset):
            profile_median_change_1_day = self.profile_median_change_1_day.to_dict()

        profile_median_change_7_days: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_median_change_7_days, Unset):
            profile_median_change_7_days = self.profile_median_change_7_days.to_dict()

        profile_median_change_30_days: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_median_change_30_days, Unset):
            profile_median_change_30_days = self.profile_median_change_30_days.to_dict()

        profile_sum_change_1_day: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_sum_change_1_day, Unset):
            profile_sum_change_1_day = self.profile_sum_change_1_day.to_dict()

        profile_sum_change_7_days: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_sum_change_7_days, Unset):
            profile_sum_change_7_days = self.profile_sum_change_7_days.to_dict()

        profile_sum_change_30_days: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_sum_change_30_days, Unset):
            profile_sum_change_30_days = self.profile_sum_change_30_days.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom_checks is not UNSET:
            field_dict["custom_checks"] = custom_checks
        if profile_sum_anomaly is not UNSET:
            field_dict["profile_sum_anomaly"] = profile_sum_anomaly
        if profile_mean_anomaly is not UNSET:
            field_dict["profile_mean_anomaly"] = profile_mean_anomaly
        if profile_median_anomaly is not UNSET:
            field_dict["profile_median_anomaly"] = profile_median_anomaly
        if profile_min_anomaly is not UNSET:
            field_dict["profile_min_anomaly"] = profile_min_anomaly
        if profile_max_anomaly is not UNSET:
            field_dict["profile_max_anomaly"] = profile_max_anomaly
        if profile_mean_change is not UNSET:
            field_dict["profile_mean_change"] = profile_mean_change
        if profile_median_change is not UNSET:
            field_dict["profile_median_change"] = profile_median_change
        if profile_sum_change is not UNSET:
            field_dict["profile_sum_change"] = profile_sum_change
        if profile_mean_change_1_day is not UNSET:
            field_dict["profile_mean_change_1_day"] = profile_mean_change_1_day
        if profile_mean_change_7_days is not UNSET:
            field_dict["profile_mean_change_7_days"] = profile_mean_change_7_days
        if profile_mean_change_30_days is not UNSET:
            field_dict["profile_mean_change_30_days"] = profile_mean_change_30_days
        if profile_median_change_1_day is not UNSET:
            field_dict["profile_median_change_1_day"] = profile_median_change_1_day
        if profile_median_change_7_days is not UNSET:
            field_dict["profile_median_change_7_days"] = profile_median_change_7_days
        if profile_median_change_30_days is not UNSET:
            field_dict["profile_median_change_30_days"] = profile_median_change_30_days
        if profile_sum_change_1_day is not UNSET:
            field_dict["profile_sum_change_1_day"] = profile_sum_change_1_day
        if profile_sum_change_7_days is not UNSET:
            field_dict["profile_sum_change_7_days"] = profile_sum_change_7_days
        if profile_sum_change_30_days is not UNSET:
            field_dict["profile_sum_change_30_days"] = profile_sum_change_30_days

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_anomaly_profiling_checks_spec_custom_checks import (
            ColumnAnomalyProfilingChecksSpecCustomChecks,
        )
        from ..models.column_max_anomaly_differencing_check_spec import (
            ColumnMaxAnomalyDifferencingCheckSpec,
        )
        from ..models.column_mean_anomaly_stationary_check_spec import (
            ColumnMeanAnomalyStationaryCheckSpec,
        )
        from ..models.column_mean_change_1_day_check_spec import (
            ColumnMeanChange1DayCheckSpec,
        )
        from ..models.column_mean_change_7_days_check_spec import (
            ColumnMeanChange7DaysCheckSpec,
        )
        from ..models.column_mean_change_30_days_check_spec import (
            ColumnMeanChange30DaysCheckSpec,
        )
        from ..models.column_mean_change_check_spec import ColumnMeanChangeCheckSpec
        from ..models.column_median_anomaly_stationary_check_spec import (
            ColumnMedianAnomalyStationaryCheckSpec,
        )
        from ..models.column_median_change_1_day_check_spec import (
            ColumnMedianChange1DayCheckSpec,
        )
        from ..models.column_median_change_7_days_check_spec import (
            ColumnMedianChange7DaysCheckSpec,
        )
        from ..models.column_median_change_30_days_check_spec import (
            ColumnMedianChange30DaysCheckSpec,
        )
        from ..models.column_median_change_check_spec import ColumnMedianChangeCheckSpec
        from ..models.column_min_anomaly_differencing_check_spec import (
            ColumnMinAnomalyDifferencingCheckSpec,
        )
        from ..models.column_sum_anomaly_differencing_check_spec import (
            ColumnSumAnomalyDifferencingCheckSpec,
        )
        from ..models.column_sum_change_1_day_check_spec import (
            ColumnSumChange1DayCheckSpec,
        )
        from ..models.column_sum_change_7_days_check_spec import (
            ColumnSumChange7DaysCheckSpec,
        )
        from ..models.column_sum_change_30_days_check_spec import (
            ColumnSumChange30DaysCheckSpec,
        )
        from ..models.column_sum_change_check_spec import ColumnSumChangeCheckSpec

        d = src_dict.copy()
        _custom_checks = d.pop("custom_checks", UNSET)
        custom_checks: Union[Unset, ColumnAnomalyProfilingChecksSpecCustomChecks]
        if isinstance(_custom_checks, Unset):
            custom_checks = UNSET
        else:
            custom_checks = ColumnAnomalyProfilingChecksSpecCustomChecks.from_dict(
                _custom_checks
            )

        _profile_sum_anomaly = d.pop("profile_sum_anomaly", UNSET)
        profile_sum_anomaly: Union[Unset, ColumnSumAnomalyDifferencingCheckSpec]
        if isinstance(_profile_sum_anomaly, Unset):
            profile_sum_anomaly = UNSET
        else:
            profile_sum_anomaly = ColumnSumAnomalyDifferencingCheckSpec.from_dict(
                _profile_sum_anomaly
            )

        _profile_mean_anomaly = d.pop("profile_mean_anomaly", UNSET)
        profile_mean_anomaly: Union[Unset, ColumnMeanAnomalyStationaryCheckSpec]
        if isinstance(_profile_mean_anomaly, Unset):
            profile_mean_anomaly = UNSET
        else:
            profile_mean_anomaly = ColumnMeanAnomalyStationaryCheckSpec.from_dict(
                _profile_mean_anomaly
            )

        _profile_median_anomaly = d.pop("profile_median_anomaly", UNSET)
        profile_median_anomaly: Union[Unset, ColumnMedianAnomalyStationaryCheckSpec]
        if isinstance(_profile_median_anomaly, Unset):
            profile_median_anomaly = UNSET
        else:
            profile_median_anomaly = ColumnMedianAnomalyStationaryCheckSpec.from_dict(
                _profile_median_anomaly
            )

        _profile_min_anomaly = d.pop("profile_min_anomaly", UNSET)
        profile_min_anomaly: Union[Unset, ColumnMinAnomalyDifferencingCheckSpec]
        if isinstance(_profile_min_anomaly, Unset):
            profile_min_anomaly = UNSET
        else:
            profile_min_anomaly = ColumnMinAnomalyDifferencingCheckSpec.from_dict(
                _profile_min_anomaly
            )

        _profile_max_anomaly = d.pop("profile_max_anomaly", UNSET)
        profile_max_anomaly: Union[Unset, ColumnMaxAnomalyDifferencingCheckSpec]
        if isinstance(_profile_max_anomaly, Unset):
            profile_max_anomaly = UNSET
        else:
            profile_max_anomaly = ColumnMaxAnomalyDifferencingCheckSpec.from_dict(
                _profile_max_anomaly
            )

        _profile_mean_change = d.pop("profile_mean_change", UNSET)
        profile_mean_change: Union[Unset, ColumnMeanChangeCheckSpec]
        if isinstance(_profile_mean_change, Unset):
            profile_mean_change = UNSET
        else:
            profile_mean_change = ColumnMeanChangeCheckSpec.from_dict(
                _profile_mean_change
            )

        _profile_median_change = d.pop("profile_median_change", UNSET)
        profile_median_change: Union[Unset, ColumnMedianChangeCheckSpec]
        if isinstance(_profile_median_change, Unset):
            profile_median_change = UNSET
        else:
            profile_median_change = ColumnMedianChangeCheckSpec.from_dict(
                _profile_median_change
            )

        _profile_sum_change = d.pop("profile_sum_change", UNSET)
        profile_sum_change: Union[Unset, ColumnSumChangeCheckSpec]
        if isinstance(_profile_sum_change, Unset):
            profile_sum_change = UNSET
        else:
            profile_sum_change = ColumnSumChangeCheckSpec.from_dict(_profile_sum_change)

        _profile_mean_change_1_day = d.pop("profile_mean_change_1_day", UNSET)
        profile_mean_change_1_day: Union[Unset, ColumnMeanChange1DayCheckSpec]
        if isinstance(_profile_mean_change_1_day, Unset):
            profile_mean_change_1_day = UNSET
        else:
            profile_mean_change_1_day = ColumnMeanChange1DayCheckSpec.from_dict(
                _profile_mean_change_1_day
            )

        _profile_mean_change_7_days = d.pop("profile_mean_change_7_days", UNSET)
        profile_mean_change_7_days: Union[Unset, ColumnMeanChange7DaysCheckSpec]
        if isinstance(_profile_mean_change_7_days, Unset):
            profile_mean_change_7_days = UNSET
        else:
            profile_mean_change_7_days = ColumnMeanChange7DaysCheckSpec.from_dict(
                _profile_mean_change_7_days
            )

        _profile_mean_change_30_days = d.pop("profile_mean_change_30_days", UNSET)
        profile_mean_change_30_days: Union[Unset, ColumnMeanChange30DaysCheckSpec]
        if isinstance(_profile_mean_change_30_days, Unset):
            profile_mean_change_30_days = UNSET
        else:
            profile_mean_change_30_days = ColumnMeanChange30DaysCheckSpec.from_dict(
                _profile_mean_change_30_days
            )

        _profile_median_change_1_day = d.pop("profile_median_change_1_day", UNSET)
        profile_median_change_1_day: Union[Unset, ColumnMedianChange1DayCheckSpec]
        if isinstance(_profile_median_change_1_day, Unset):
            profile_median_change_1_day = UNSET
        else:
            profile_median_change_1_day = ColumnMedianChange1DayCheckSpec.from_dict(
                _profile_median_change_1_day
            )

        _profile_median_change_7_days = d.pop("profile_median_change_7_days", UNSET)
        profile_median_change_7_days: Union[Unset, ColumnMedianChange7DaysCheckSpec]
        if isinstance(_profile_median_change_7_days, Unset):
            profile_median_change_7_days = UNSET
        else:
            profile_median_change_7_days = ColumnMedianChange7DaysCheckSpec.from_dict(
                _profile_median_change_7_days
            )

        _profile_median_change_30_days = d.pop("profile_median_change_30_days", UNSET)
        profile_median_change_30_days: Union[Unset, ColumnMedianChange30DaysCheckSpec]
        if isinstance(_profile_median_change_30_days, Unset):
            profile_median_change_30_days = UNSET
        else:
            profile_median_change_30_days = ColumnMedianChange30DaysCheckSpec.from_dict(
                _profile_median_change_30_days
            )

        _profile_sum_change_1_day = d.pop("profile_sum_change_1_day", UNSET)
        profile_sum_change_1_day: Union[Unset, ColumnSumChange1DayCheckSpec]
        if isinstance(_profile_sum_change_1_day, Unset):
            profile_sum_change_1_day = UNSET
        else:
            profile_sum_change_1_day = ColumnSumChange1DayCheckSpec.from_dict(
                _profile_sum_change_1_day
            )

        _profile_sum_change_7_days = d.pop("profile_sum_change_7_days", UNSET)
        profile_sum_change_7_days: Union[Unset, ColumnSumChange7DaysCheckSpec]
        if isinstance(_profile_sum_change_7_days, Unset):
            profile_sum_change_7_days = UNSET
        else:
            profile_sum_change_7_days = ColumnSumChange7DaysCheckSpec.from_dict(
                _profile_sum_change_7_days
            )

        _profile_sum_change_30_days = d.pop("profile_sum_change_30_days", UNSET)
        profile_sum_change_30_days: Union[Unset, ColumnSumChange30DaysCheckSpec]
        if isinstance(_profile_sum_change_30_days, Unset):
            profile_sum_change_30_days = UNSET
        else:
            profile_sum_change_30_days = ColumnSumChange30DaysCheckSpec.from_dict(
                _profile_sum_change_30_days
            )

        column_anomaly_profiling_checks_spec = cls(
            custom_checks=custom_checks,
            profile_sum_anomaly=profile_sum_anomaly,
            profile_mean_anomaly=profile_mean_anomaly,
            profile_median_anomaly=profile_median_anomaly,
            profile_min_anomaly=profile_min_anomaly,
            profile_max_anomaly=profile_max_anomaly,
            profile_mean_change=profile_mean_change,
            profile_median_change=profile_median_change,
            profile_sum_change=profile_sum_change,
            profile_mean_change_1_day=profile_mean_change_1_day,
            profile_mean_change_7_days=profile_mean_change_7_days,
            profile_mean_change_30_days=profile_mean_change_30_days,
            profile_median_change_1_day=profile_median_change_1_day,
            profile_median_change_7_days=profile_median_change_7_days,
            profile_median_change_30_days=profile_median_change_30_days,
            profile_sum_change_1_day=profile_sum_change_1_day,
            profile_sum_change_7_days=profile_sum_change_7_days,
            profile_sum_change_30_days=profile_sum_change_30_days,
        )

        column_anomaly_profiling_checks_spec.additional_properties = d
        return column_anomaly_profiling_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_schema_column_count_changed_check_spec import (
        TableSchemaColumnCountChangedCheckSpec,
    )
    from ..models.table_schema_column_count_check_spec import (
        TableSchemaColumnCountCheckSpec,
    )
    from ..models.table_schema_column_list_changed_check_spec import (
        TableSchemaColumnListChangedCheckSpec,
    )
    from ..models.table_schema_column_list_or_order_changed_check_spec import (
        TableSchemaColumnListOrOrderChangedCheckSpec,
    )
    from ..models.table_schema_column_types_changed_check_spec import (
        TableSchemaColumnTypesChangedCheckSpec,
    )
    from ..models.table_schema_profiling_checks_spec_custom_checks import (
        TableSchemaProfilingChecksSpecCustomChecks,
    )


T = TypeVar("T", bound="TableSchemaProfilingChecksSpec")


@_attrs_define
class TableSchemaProfilingChecksSpec:
    """
    Attributes:
        custom_checks (Union[Unset, TableSchemaProfilingChecksSpecCustomChecks]): Dictionary of additional custom checks
            within this category. The keys are check names defined in the definition section. The sensor parameters and
            rules should match the type of the configured sensor and rule for the custom check.
        profile_column_count (Union[Unset, TableSchemaColumnCountCheckSpec]):
        profile_column_count_changed (Union[Unset, TableSchemaColumnCountChangedCheckSpec]):
        profile_column_list_changed (Union[Unset, TableSchemaColumnListChangedCheckSpec]):
        profile_column_list_or_order_changed (Union[Unset, TableSchemaColumnListOrOrderChangedCheckSpec]):
        profile_column_types_changed (Union[Unset, TableSchemaColumnTypesChangedCheckSpec]):
    """

    custom_checks: Union[Unset, "TableSchemaProfilingChecksSpecCustomChecks"] = UNSET
    profile_column_count: Union[Unset, "TableSchemaColumnCountCheckSpec"] = UNSET
    profile_column_count_changed: Union[
        Unset, "TableSchemaColumnCountChangedCheckSpec"
    ] = UNSET
    profile_column_list_changed: Union[
        Unset, "TableSchemaColumnListChangedCheckSpec"
    ] = UNSET
    profile_column_list_or_order_changed: Union[
        Unset, "TableSchemaColumnListOrOrderChangedCheckSpec"
    ] = UNSET
    profile_column_types_changed: Union[
        Unset, "TableSchemaColumnTypesChangedCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_checks, Unset):
            custom_checks = self.custom_checks.to_dict()

        profile_column_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_column_count, Unset):
            profile_column_count = self.profile_column_count.to_dict()

        profile_column_count_changed: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_column_count_changed, Unset):
            profile_column_count_changed = self.profile_column_count_changed.to_dict()

        profile_column_list_changed: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_column_list_changed, Unset):
            profile_column_list_changed = self.profile_column_list_changed.to_dict()

        profile_column_list_or_order_changed: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_column_list_or_order_changed, Unset):
            profile_column_list_or_order_changed = (
                self.profile_column_list_or_order_changed.to_dict()
            )

        profile_column_types_changed: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_column_types_changed, Unset):
            profile_column_types_changed = self.profile_column_types_changed.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom_checks is not UNSET:
            field_dict["custom_checks"] = custom_checks
        if profile_column_count is not UNSET:
            field_dict["profile_column_count"] = profile_column_count
        if profile_column_count_changed is not UNSET:
            field_dict["profile_column_count_changed"] = profile_column_count_changed
        if profile_column_list_changed is not UNSET:
            field_dict["profile_column_list_changed"] = profile_column_list_changed
        if profile_column_list_or_order_changed is not UNSET:
            field_dict["profile_column_list_or_order_changed"] = (
                profile_column_list_or_order_changed
            )
        if profile_column_types_changed is not UNSET:
            field_dict["profile_column_types_changed"] = profile_column_types_changed

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_schema_column_count_changed_check_spec import (
            TableSchemaColumnCountChangedCheckSpec,
        )
        from ..models.table_schema_column_count_check_spec import (
            TableSchemaColumnCountCheckSpec,
        )
        from ..models.table_schema_column_list_changed_check_spec import (
            TableSchemaColumnListChangedCheckSpec,
        )
        from ..models.table_schema_column_list_or_order_changed_check_spec import (
            TableSchemaColumnListOrOrderChangedCheckSpec,
        )
        from ..models.table_schema_column_types_changed_check_spec import (
            TableSchemaColumnTypesChangedCheckSpec,
        )
        from ..models.table_schema_profiling_checks_spec_custom_checks import (
            TableSchemaProfilingChecksSpecCustomChecks,
        )

        d = src_dict.copy()
        _custom_checks = d.pop("custom_checks", UNSET)
        custom_checks: Union[Unset, TableSchemaProfilingChecksSpecCustomChecks]
        if isinstance(_custom_checks, Unset):
            custom_checks = UNSET
        else:
            custom_checks = TableSchemaProfilingChecksSpecCustomChecks.from_dict(
                _custom_checks
            )

        _profile_column_count = d.pop("profile_column_count", UNSET)
        profile_column_count: Union[Unset, TableSchemaColumnCountCheckSpec]
        if isinstance(_profile_column_count, Unset):
            profile_column_count = UNSET
        else:
            profile_column_count = TableSchemaColumnCountCheckSpec.from_dict(
                _profile_column_count
            )

        _profile_column_count_changed = d.pop("profile_column_count_changed", UNSET)
        profile_column_count_changed: Union[
            Unset, TableSchemaColumnCountChangedCheckSpec
        ]
        if isinstance(_profile_column_count_changed, Unset):
            profile_column_count_changed = UNSET
        else:
            profile_column_count_changed = (
                TableSchemaColumnCountChangedCheckSpec.from_dict(
                    _profile_column_count_changed
                )
            )

        _profile_column_list_changed = d.pop("profile_column_list_changed", UNSET)
        profile_column_list_changed: Union[Unset, TableSchemaColumnListChangedCheckSpec]
        if isinstance(_profile_column_list_changed, Unset):
            profile_column_list_changed = UNSET
        else:
            profile_column_list_changed = (
                TableSchemaColumnListChangedCheckSpec.from_dict(
                    _profile_column_list_changed
                )
            )

        _profile_column_list_or_order_changed = d.pop(
            "profile_column_list_or_order_changed", UNSET
        )
        profile_column_list_or_order_changed: Union[
            Unset, TableSchemaColumnListOrOrderChangedCheckSpec
        ]
        if isinstance(_profile_column_list_or_order_changed, Unset):
            profile_column_list_or_order_changed = UNSET
        else:
            profile_column_list_or_order_changed = (
                TableSchemaColumnListOrOrderChangedCheckSpec.from_dict(
                    _profile_column_list_or_order_changed
                )
            )

        _profile_column_types_changed = d.pop("profile_column_types_changed", UNSET)
        profile_column_types_changed: Union[
            Unset, TableSchemaColumnTypesChangedCheckSpec
        ]
        if isinstance(_profile_column_types_changed, Unset):
            profile_column_types_changed = UNSET
        else:
            profile_column_types_changed = (
                TableSchemaColumnTypesChangedCheckSpec.from_dict(
                    _profile_column_types_changed
                )
            )

        table_schema_profiling_checks_spec = cls(
            custom_checks=custom_checks,
            profile_column_count=profile_column_count,
            profile_column_count_changed=profile_column_count_changed,
            profile_column_list_changed=profile_column_list_changed,
            profile_column_list_or_order_changed=profile_column_list_or_order_changed,
            profile_column_types_changed=profile_column_types_changed,
        )

        table_schema_profiling_checks_spec.additional_properties = d
        return table_schema_profiling_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.dqo_job_status import DqoJobStatus
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.dqo_queue_job_id import DqoQueueJobId
    from ..models.error_sampler_result import ErrorSamplerResult


T = TypeVar("T", bound="CollectErrorSamplesResult")


@_attrs_define
class CollectErrorSamplesResult:
    """Object returned from the operation that queues a "collect error samples" job. The result contains the job id that
    was started and optionally can also contain the result of collecting the error samples  if the operation was started
    with wait=true parameter to wait for the "collect error samples" job to finish.

        Attributes:
            job_id (Union[Unset, DqoQueueJobId]): Identifies a single job that was pushed to the job queue.
            result (Union[Unset, ErrorSamplerResult]): Returns the result with the summary of the error samples collected.
            status (Union[Unset, DqoJobStatus]):
    """

    job_id: Union[Unset, "DqoQueueJobId"] = UNSET
    result: Union[Unset, "ErrorSamplerResult"] = UNSET
    status: Union[Unset, DqoJobStatus] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        job_id: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.job_id, Unset):
            job_id = self.job_id.to_dict()

        result: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.result, Unset):
            result = self.result.to_dict()

        status: Union[Unset, str] = UNSET
        if not isinstance(self.status, Unset):
            status = self.status.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if job_id is not UNSET:
            field_dict["jobId"] = job_id
        if result is not UNSET:
            field_dict["result"] = result
        if status is not UNSET:
            field_dict["status"] = status

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.dqo_queue_job_id import DqoQueueJobId
        from ..models.error_sampler_result import ErrorSamplerResult

        d = src_dict.copy()
        _job_id = d.pop("jobId", UNSET)
        job_id: Union[Unset, DqoQueueJobId]
        if isinstance(_job_id, Unset):
            job_id = UNSET
        else:
            job_id = DqoQueueJobId.from_dict(_job_id)

        _result = d.pop("result", UNSET)
        result: Union[Unset, ErrorSamplerResult]
        if isinstance(_result, Unset):
            result = UNSET
        else:
            result = ErrorSamplerResult.from_dict(_result)

        _status = d.pop("status", UNSET)
        status: Union[Unset, DqoJobStatus]
        if isinstance(_status, Unset):
            status = UNSET
        else:
            status = DqoJobStatus(_status)

        collect_error_samples_result = cls(
            job_id=job_id,
            result=result,
            status=status,
        )

        collect_error_samples_result.additional_properties = d
        return collect_error_samples_result

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.incident_notification_spec_filtered_notifications import (
        IncidentNotificationSpecFilteredNotifications,
    )


T = TypeVar("T", bound="IncidentNotificationSpec")


@_attrs_define
class IncidentNotificationSpec:
    """
    Attributes:
        incident_opened_addresses (Union[Unset, str]): Notification address(es) where the notification messages
            describing new incidents are pushed using a HTTP POST request (for webhook address) or an SMTP (for email
            address). The format of the JSON message is documented in the IncidentNotificationMessage object.
        incident_acknowledged_addresses (Union[Unset, str]): Notification address(es) where the notification messages
            describing acknowledged messages are pushed using a HTTP POST request (for webhook address) or an SMTP (for
            email address). The format of the JSON message is documented in the IncidentNotificationMessage object.
        incident_resolved_addresses (Union[Unset, str]): Notification address(es) where the notification messages
            describing resolved messages are pushed using a HTTP POST request (for webhook address) or an SMTP (for email
            address). The format of the JSON message is documented in the IncidentNotificationMessage object.
        incident_muted_addresses (Union[Unset, str]): Notification address(es) where the notification messages
            describing muted messages are pushed using a HTTP POST request (for webhook address) or an SMTP (for email
            address). The format of the JSON message is documented in the IncidentNotificationMessage object.
        filtered_notifications (Union[Unset, IncidentNotificationSpecFilteredNotifications]): Filtered notifications map
            with filter configuration and notification addresses treated with higher priority than those from the current
            class.
    """

    incident_opened_addresses: Union[Unset, str] = UNSET
    incident_acknowledged_addresses: Union[Unset, str] = UNSET
    incident_resolved_addresses: Union[Unset, str] = UNSET
    incident_muted_addresses: Union[Unset, str] = UNSET
    filtered_notifications: Union[
        Unset, "IncidentNotificationSpecFilteredNotifications"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        incident_opened_addresses = self.incident_opened_addresses
        incident_acknowledged_addresses = self.incident_acknowledged_addresses
        incident_resolved_addresses = self.incident_resolved_addresses
        incident_muted_addresses = self.incident_muted_addresses
        filtered_notifications: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.filtered_notifications, Unset):
            filtered_notifications = self.filtered_notifications.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if incident_opened_addresses is not UNSET:
            field_dict["incident_opened_addresses"] = incident_opened_addresses
        if incident_acknowledged_addresses is not UNSET:
            field_dict["incident_acknowledged_addresses"] = (
                incident_acknowledged_addresses
            )
        if incident_resolved_addresses is not UNSET:
            field_dict["incident_resolved_addresses"] = incident_resolved_addresses
        if incident_muted_addresses is not UNSET:
            field_dict["incident_muted_addresses"] = incident_muted_addresses
        if filtered_notifications is not UNSET:
            field_dict["filtered_notifications"] = filtered_notifications

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.incident_notification_spec_filtered_notifications import (
            IncidentNotificationSpecFilteredNotifications,
        )

        d = src_dict.copy()
        incident_opened_addresses = d.pop("incident_opened_addresses", UNSET)

        incident_acknowledged_addresses = d.pop(
            "incident_acknowledged_addresses", UNSET
        )

        incident_resolved_addresses = d.pop("incident_resolved_addresses", UNSET)

        incident_muted_addresses = d.pop("incident_muted_addresses", UNSET)

        _filtered_notifications = d.pop("filtered_notifications", UNSET)
        filtered_notifications: Union[
            Unset, IncidentNotificationSpecFilteredNotifications
        ]
        if isinstance(_filtered_notifications, Unset):
            filtered_notifications = UNSET
        else:
            filtered_notifications = (
                IncidentNotificationSpecFilteredNotifications.from_dict(
                    _filtered_notifications
                )
            )

        incident_notification_spec = cls(
            incident_opened_addresses=incident_opened_addresses,
            incident_acknowledged_addresses=incident_acknowledged_addresses,
            incident_resolved_addresses=incident_resolved_addresses,
            incident_muted_addresses=incident_muted_addresses,
            filtered_notifications=filtered_notifications,
        )

        incident_notification_spec.additional_properties = d
        return incident_notification_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="MinPercentRule100ErrorParametersSpec")


@_attrs_define
class MinPercentRule100ErrorParametersSpec:
    """
    Attributes:
        min_percent (Union[Unset, float]): Minimum accepted value for the actual_value returned by the sensor
            (inclusive).
    """

    min_percent: Union[Unset, float] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        min_percent = self.min_percent

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if min_percent is not UNSET:
            field_dict["min_percent"] = min_percent

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        min_percent = d.pop("min_percent", UNSET)

        min_percent_rule_100_error_parameters_spec = cls(
            min_percent=min_percent,
        )

        min_percent_rule_100_error_parameters_spec.additional_properties = d
        return min_percent_rule_100_error_parameters_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_lineage_source_spec_columns import TableLineageSourceSpecColumns
    from ..models.table_lineage_source_spec_properties import (
        TableLineageSourceSpecProperties,
    )


T = TypeVar("T", bound="TableLineageSourceSpec")


@_attrs_define
class TableLineageSourceSpec:
    """
    Attributes:
        source_connection (Union[Unset, str]): The name of a source connection that is defined in DQOps and contains a
            source table from which the current table receives data.
        source_schema (Union[Unset, str]): The name of a source schema within the source connection that contains a
            source table from which the current table receives data.
        source_table (Union[Unset, str]): The name of a source table in the source schema from which the current table
            receives data.
        data_lineage_source_tool (Union[Unset, str]): The name of a source tool from which this data lineage information
            was copied. This field should be filled when the data lineage was imported from another data catalog or a data
            lineage tracking platform.
        properties (Union[Unset, TableLineageSourceSpecProperties]): A dictionary of mapping properties stored as a
            key/value dictionary. Data lineage synchronization tools that are importing data lineage mappings from external
            data lineage sources can use it to store mapping information.
        columns (Union[Unset, TableLineageSourceSpecColumns]): Configuration of source columns for each column in the
            current table. The keys in this dictionary are column names in the current table. The object stored in the
            dictionary contain a list of source columns.
    """

    source_connection: Union[Unset, str] = UNSET
    source_schema: Union[Unset, str] = UNSET
    source_table: Union[Unset, str] = UNSET
    data_lineage_source_tool: Union[Unset, str] = UNSET
    properties: Union[Unset, "TableLineageSourceSpecProperties"] = UNSET
    columns: Union[Unset, "TableLineageSourceSpecColumns"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        source_connection = self.source_connection
        source_schema = self.source_schema
        source_table = self.source_table
        data_lineage_source_tool = self.data_lineage_source_tool
        properties: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.properties, Unset):
            properties = self.properties.to_dict()

        columns: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.columns, Unset):
            columns = self.columns.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if source_connection is not UNSET:
            field_dict["source_connection"] = source_connection
        if source_schema is not UNSET:
            field_dict["source_schema"] = source_schema
        if source_table is not UNSET:
            field_dict["source_table"] = source_table
        if data_lineage_source_tool is not UNSET:
            field_dict["data_lineage_source_tool"] = data_lineage_source_tool
        if properties is not UNSET:
            field_dict["properties"] = properties
        if columns is not UNSET:
            field_dict["columns"] = columns

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_lineage_source_spec_columns import (
            TableLineageSourceSpecColumns,
        )
        from ..models.table_lineage_source_spec_properties import (
            TableLineageSourceSpecProperties,
        )

        d = src_dict.copy()
        source_connection = d.pop("source_connection", UNSET)

        source_schema = d.pop("source_schema", UNSET)

        source_table = d.pop("source_table", UNSET)

        data_lineage_source_tool = d.pop("data_lineage_source_tool", UNSET)

        _properties = d.pop("properties", UNSET)
        properties: Union[Unset, TableLineageSourceSpecProperties]
        if isinstance(_properties, Unset):
            properties = UNSET
        else:
            properties = TableLineageSourceSpecProperties.from_dict(_properties)

        _columns = d.pop("columns", UNSET)
        columns: Union[Unset, TableLineageSourceSpecColumns]
        if isinstance(_columns, Unset):
            columns = UNSET
        else:
            columns = TableLineageSourceSpecColumns.from_dict(_columns)

        table_lineage_source_spec = cls(
            source_connection=source_connection,
            source_schema=source_schema,
            source_table=source_table,
            data_lineage_source_tool=data_lineage_source_tool,
            properties=properties,
            columns=columns,
        )

        table_lineage_source_spec.additional_properties = d
        return table_lineage_source_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="TableComparisonGroupingColumnsPairSpec")


@_attrs_define
class TableComparisonGroupingColumnsPairSpec:
    """
    Attributes:
        compared_table_column_name (Union[Unset, str]): The name of the column on the compared table (the parent table)
            that is used in the GROUP BY clause to group rows before compared aggregates (row counts, sums, etc.) are
            calculated. This column is also used to join (match) results to the reference table.
        reference_table_column_name (Union[Unset, str]): The name of the column on the reference table (the source of
            truth) that is used in the GROUP BY clause to group rows before compared aggregates (row counts, sums, etc.) are
            calculated. This column is also used to join (match) results to the compared table.
    """

    compared_table_column_name: Union[Unset, str] = UNSET
    reference_table_column_name: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        compared_table_column_name = self.compared_table_column_name
        reference_table_column_name = self.reference_table_column_name

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if compared_table_column_name is not UNSET:
            field_dict["compared_table_column_name"] = compared_table_column_name
        if reference_table_column_name is not UNSET:
            field_dict["reference_table_column_name"] = reference_table_column_name

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        compared_table_column_name = d.pop("compared_table_column_name", UNSET)

        reference_table_column_name = d.pop("reference_table_column_name", UNSET)

        table_comparison_grouping_columns_pair_spec = cls(
            compared_table_column_name=compared_table_column_name,
            reference_table_column_name=reference_table_column_name,
        )

        table_comparison_grouping_columns_pair_spec.additional_properties = d
        return table_comparison_grouping_columns_pair_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.check_target import CheckTarget
from ..models.check_time_scale import CheckTimeScale
from ..models.check_type import CheckType
from ..types import UNSET, Unset

T = TypeVar("T", bound="SimilarCheckModel")


@_attrs_define
class SimilarCheckModel:
    """Model that identifies a similar check in another category or another type of check (monitoring, partition).

    Attributes:
        check_target (Union[Unset, CheckTarget]):
        check_type (Union[Unset, CheckType]):
        time_scale (Union[Unset, CheckTimeScale]):
        category (Union[Unset, str]): The check's category.
        check_name (Union[Unset, str]): Similar check name in another category.
    """

    check_target: Union[Unset, CheckTarget] = UNSET
    check_type: Union[Unset, CheckType] = UNSET
    time_scale: Union[Unset, CheckTimeScale] = UNSET
    category: Union[Unset, str] = UNSET
    check_name: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        check_target: Union[Unset, str] = UNSET
        if not isinstance(self.check_target, Unset):
            check_target = self.check_target.value

        check_type: Union[Unset, str] = UNSET
        if not isinstance(self.check_type, Unset):
            check_type = self.check_type.value

        time_scale: Union[Unset, str] = UNSET
        if not isinstance(self.time_scale, Unset):
            time_scale = self.time_scale.value

        category = self.category
        check_name = self.check_name

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if check_target is not UNSET:
            field_dict["check_target"] = check_target
        if check_type is not UNSET:
            field_dict["check_type"] = check_type
        if time_scale is not UNSET:
            field_dict["time_scale"] = time_scale
        if category is not UNSET:
            field_dict["category"] = category
        if check_name is not UNSET:
            field_dict["check_name"] = check_name

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _check_target = d.pop("check_target", UNSET)
        check_target: Union[Unset, CheckTarget]
        if isinstance(_check_target, Unset):
            check_target = UNSET
        else:
            check_target = CheckTarget(_check_target)

        _check_type = d.pop("check_type", UNSET)
        check_type: Union[Unset, CheckType]
        if isinstance(_check_type, Unset):
            check_type = UNSET
        else:
            check_type = CheckType(_check_type)

        _time_scale = d.pop("time_scale", UNSET)
        time_scale: Union[Unset, CheckTimeScale]
        if isinstance(_time_scale, Unset):
            time_scale = UNSET
        else:
            time_scale = CheckTimeScale(_time_scale)

        category = d.pop("category", UNSET)

        check_name = d.pop("check_name", UNSET)

        similar_check_model = cls(
            check_target=check_target,
            check_type=check_type,
            time_scale=time_scale,
            category=category,
            check_name=check_name,
        )

        similar_check_model.additional_properties = d
        return similar_check_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="TableOwnerSpec")


@_attrs_define
class TableOwnerSpec:
    """
    Attributes:
        data_steward (Union[Unset, str]): Data steward name
        application (Union[Unset, str]): Business application name
    """

    data_steward: Union[Unset, str] = UNSET
    application: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        data_steward = self.data_steward
        application = self.application

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if data_steward is not UNSET:
            field_dict["data_steward"] = data_steward
        if application is not UNSET:
            field_dict["application"] = application

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        data_steward = d.pop("data_steward", UNSET)

        application = d.pop("application", UNSET)

        table_owner_spec = cls(
            data_steward=data_steward,
            application=application,
        )

        table_owner_spec.additional_properties = d
        return table_owner_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.run_checks_queue_job_result import RunChecksQueueJobResult
from ...types import UNSET, Response, Unset


def _get_kwargs(
    job_id: str,
    *,
    wait_timeout: Union[Unset, None, int] = UNSET,
) -> Dict[str, Any]:

    pass

    params: Dict[str, Any] = {}
    params["waitTimeout"] = wait_timeout

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": "api/jobs/runchecks/{jobId}/wait".format(
            jobId=job_id,
        ),
        "params": params,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[RunChecksQueueJobResult]:
    if response.status_code == HTTPStatus.OK:
        response_200 = RunChecksQueueJobResult.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[RunChecksQueueJobResult]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    job_id: str,
    *,
    client: AuthenticatedClient,
    wait_timeout: Union[Unset, None, int] = UNSET,
) -> Response[RunChecksQueueJobResult]:
    """waitForRunChecksJob

     Waits for a job to finish. Returns the status of a finished job or a current state of a job that is
    still running, but the wait timeout elapsed.

    Args:
        job_id (str):
        wait_timeout (Union[Unset, None, int]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[RunChecksQueueJobResult]
    """

    kwargs = _get_kwargs(
        job_id=job_id,
        wait_timeout=wait_timeout,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    job_id: str,
    *,
    client: AuthenticatedClient,
    wait_timeout: Union[Unset, None, int] = UNSET,
) -> Optional[RunChecksQueueJobResult]:
    """waitForRunChecksJob

     Waits for a job to finish. Returns the status of a finished job or a current state of a job that is
    still running, but the wait timeout elapsed.

    Args:
        job_id (str):
        wait_timeout (Union[Unset, None, int]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        RunChecksQueueJobResult
    """

    return sync_detailed(
        job_id=job_id,
        client=client,
        wait_timeout=wait_timeout,
    ).parsed


async def asyncio_detailed(
    job_id: str,
    *,
    client: AuthenticatedClient,
    wait_timeout: Union[Unset, None, int] = UNSET,
) -> Response[RunChecksQueueJobResult]:
    """waitForRunChecksJob

     Waits for a job to finish. Returns the status of a finished job or a current state of a job that is
    still running, but the wait timeout elapsed.

    Args:
        job_id (str):
        wait_timeout (Union[Unset, None, int]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[RunChecksQueueJobResult]
    """

    kwargs = _get_kwargs(
        job_id=job_id,
        wait_timeout=wait_timeout,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    job_id: str,
    *,
    client: AuthenticatedClient,
    wait_timeout: Union[Unset, None, int] = UNSET,
) -> Optional[RunChecksQueueJobResult]:
    """waitForRunChecksJob

     Waits for a job to finish. Returns the status of a finished job or a current state of a job that is
    still running, but the wait timeout elapsed.

    Args:
        job_id (str):
        wait_timeout (Union[Unset, None, int]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        RunChecksQueueJobResult
    """

    return (
        await asyncio_detailed(
            job_id=job_id,
            client=client,
            wait_timeout=wait_timeout,
        )
    ).parsed



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_current_data_quality_status_model import (
        TableCurrentDataQualityStatusModel,
    )
    from ..models.table_lineage_table_list_model_properties import (
        TableLineageTableListModelProperties,
    )


T = TypeVar("T", bound="TableLineageTableListModel")


@_attrs_define
class TableLineageTableListModel:
    """Data lineage model that describes one source or target table of the current table.

    Attributes:
        target_connection (Union[Unset, str]): The connection name where the target table is defined.
        target_schema (Union[Unset, str]): The schema name in the target connection where the target table is defined.
        target_table (Union[Unset, str]): The name of the target table inside the target schema.
        source_connection (Union[Unset, str]): The name of a source connection that is defined in DQOps and contains a
            source table from which the current table receives data.
        source_schema (Union[Unset, str]): The name of a source schema within the source connection that contains a
            source table from which the current table receives data.
        source_table (Union[Unset, str]): The name of a source schema within the source connection that contains a
            source table from which the current table receives data.
        data_lineage_source_tool (Union[Unset, str]): The name of a source tool from which this data lineage information
            was copied. This field should be filled when the data lineage was imported from another data catalog or a data
            lineage tracking platform.
        properties (Union[Unset, TableLineageTableListModelProperties]): A dictionary of mapping properties stored as a
            key/value dictionary. Data lineage synchronization tools that are importing data lineage mappings from external
            data lineage sources can use it to store mapping information.
        can_edit (Union[Unset, bool]): Boolean flag that decides if the current user can update or delete this object.
        table_data_quality_status (Union[Unset, TableCurrentDataQualityStatusModel]): The table's most recent data
            quality status. It is a summary of the results of the most recently executed data quality checks on the table.
            Verify the value of the highest_severity_level to see if there are any data quality issues on the table. The
            values of severity levels are: 0 - all data quality checks passed, 1 - a warning was detected, 2 - an error was
            detected, 3 - a fatal data quality issue was detected.
    """

    target_connection: Union[Unset, str] = UNSET
    target_schema: Union[Unset, str] = UNSET
    target_table: Union[Unset, str] = UNSET
    source_connection: Union[Unset, str] = UNSET
    source_schema: Union[Unset, str] = UNSET
    source_table: Union[Unset, str] = UNSET
    data_lineage_source_tool: Union[Unset, str] = UNSET
    properties: Union[Unset, "TableLineageTableListModelProperties"] = UNSET
    can_edit: Union[Unset, bool] = UNSET
    table_data_quality_status: Union[Unset, "TableCurrentDataQualityStatusModel"] = (
        UNSET
    )
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        target_connection = self.target_connection
        target_schema = self.target_schema
        target_table = self.target_table
        source_connection = self.source_connection
        source_schema = self.source_schema
        source_table = self.source_table
        data_lineage_source_tool = self.data_lineage_source_tool
        properties: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.properties, Unset):
            properties = self.properties.to_dict()

        can_edit = self.can_edit
        table_data_quality_status: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.table_data_quality_status, Unset):
            table_data_quality_status = self.table_data_quality_status.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if target_connection is not UNSET:
            field_dict["target_connection"] = target_connection
        if target_schema is not UNSET:
            field_dict["target_schema"] = target_schema
        if target_table is not UNSET:
            field_dict["target_table"] = target_table
        if source_connection is not UNSET:
            field_dict["source_connection"] = source_connection
        if source_schema is not UNSET:
            field_dict["source_schema"] = source_schema
        if source_table is not UNSET:
            field_dict["source_table"] = source_table
        if data_lineage_source_tool is not UNSET:
            field_dict["data_lineage_source_tool"] = data_lineage_source_tool
        if properties is not UNSET:
            field_dict["properties"] = properties
        if can_edit is not UNSET:
            field_dict["can_edit"] = can_edit
        if table_data_quality_status is not UNSET:
            field_dict["table_data_quality_status"] = table_data_quality_status

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_current_data_quality_status_model import (
            TableCurrentDataQualityStatusModel,
        )
        from ..models.table_lineage_table_list_model_properties import (
            TableLineageTableListModelProperties,
        )

        d = src_dict.copy()
        target_connection = d.pop("target_connection", UNSET)

        target_schema = d.pop("target_schema", UNSET)

        target_table = d.pop("target_table", UNSET)

        source_connection = d.pop("source_connection", UNSET)

        source_schema = d.pop("source_schema", UNSET)

        source_table = d.pop("source_table", UNSET)

        data_lineage_source_tool = d.pop("data_lineage_source_tool", UNSET)

        _properties = d.pop("properties", UNSET)
        properties: Union[Unset, TableLineageTableListModelProperties]
        if isinstance(_properties, Unset):
            properties = UNSET
        else:
            properties = TableLineageTableListModelProperties.from_dict(_properties)

        can_edit = d.pop("can_edit", UNSET)

        _table_data_quality_status = d.pop("table_data_quality_status", UNSET)
        table_data_quality_status: Union[Unset, TableCurrentDataQualityStatusModel]
        if isinstance(_table_data_quality_status, Unset):
            table_data_quality_status = UNSET
        else:
            table_data_quality_status = TableCurrentDataQualityStatusModel.from_dict(
                _table_data_quality_status
            )

        table_lineage_table_list_model = cls(
            target_connection=target_connection,
            target_schema=target_schema,
            target_table=target_table,
            source_connection=source_connection,
            source_schema=source_schema,
            source_table=source_table,
            data_lineage_source_tool=data_lineage_source_tool,
            properties=properties,
            can_edit=can_edit,
            table_data_quality_status=table_data_quality_status,
        )

        table_lineage_table_list_model.additional_properties = d
        return table_lineage_table_list_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.rule_parameters_model import RuleParametersModel


T = TypeVar("T", bound="RuleThresholdsModel")


@_attrs_define
class RuleThresholdsModel:
    """Model that returns the form definition and the form data to edit a single rule with all three threshold levels (low,
    medium, high).

        Attributes:
            error (Union[Unset, RuleParametersModel]): Model that returns the form definition and the form data to edit
                parameters (thresholds) for a rule at a single severity level (low, medium, high).
            warning (Union[Unset, RuleParametersModel]): Model that returns the form definition and the form data to edit
                parameters (thresholds) for a rule at a single severity level (low, medium, high).
            fatal (Union[Unset, RuleParametersModel]): Model that returns the form definition and the form data to edit
                parameters (thresholds) for a rule at a single severity level (low, medium, high).
    """

    error: Union[Unset, "RuleParametersModel"] = UNSET
    warning: Union[Unset, "RuleParametersModel"] = UNSET
    fatal: Union[Unset, "RuleParametersModel"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        error: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.error, Unset):
            error = self.error.to_dict()

        warning: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.warning, Unset):
            warning = self.warning.to_dict()

        fatal: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.fatal, Unset):
            fatal = self.fatal.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if error is not UNSET:
            field_dict["error"] = error
        if warning is not UNSET:
            field_dict["warning"] = warning
        if fatal is not UNSET:
            field_dict["fatal"] = fatal

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.rule_parameters_model import RuleParametersModel

        d = src_dict.copy()
        _error = d.pop("error", UNSET)
        error: Union[Unset, RuleParametersModel]
        if isinstance(_error, Unset):
            error = UNSET
        else:
            error = RuleParametersModel.from_dict(_error)

        _warning = d.pop("warning", UNSET)
        warning: Union[Unset, RuleParametersModel]
        if isinstance(_warning, Unset):
            warning = UNSET
        else:
            warning = RuleParametersModel.from_dict(_warning)

        _fatal = d.pop("fatal", UNSET)
        fatal: Union[Unset, RuleParametersModel]
        if isinstance(_fatal, Unset):
            fatal = UNSET
        else:
            fatal = RuleParametersModel.from_dict(_fatal)

        rule_thresholds_model = cls(
            error=error,
            warning=warning,
            fatal=fatal,
        )

        rule_thresholds_model.additional_properties = d
        return rule_thresholds_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.field_model import FieldModel


T = TypeVar("T", bound="RuleParametersModel")


@_attrs_define
class RuleParametersModel:
    """Model that returns the form definition and the form data to edit parameters (thresholds) for a rule at a single
    severity level (low, medium, high).

        Attributes:
            rule_name (Union[Unset, str]): Full rule name. This field is for information purposes and can be used to create
                additional custom checks that reuse the same data quality rule.
            rule_parameters (Union[Unset, List['FieldModel']]): List of fields for editing the rule parameters like
                thresholds.
            disabled (Union[Unset, bool]): Disable the rule. The rule will not be evaluated. The sensor will also not be
                executed if it has no enabled rules.
            configured (Union[Unset, bool]): Returns true when the rule is configured (is not null), so it should be shown
                in the UI as configured (having values).
    """

    rule_name: Union[Unset, str] = UNSET
    rule_parameters: Union[Unset, List["FieldModel"]] = UNSET
    disabled: Union[Unset, bool] = UNSET
    configured: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        rule_name = self.rule_name
        rule_parameters: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.rule_parameters, Unset):
            rule_parameters = []
            for rule_parameters_item_data in self.rule_parameters:
                rule_parameters_item = rule_parameters_item_data.to_dict()

                rule_parameters.append(rule_parameters_item)

        disabled = self.disabled
        configured = self.configured

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if rule_name is not UNSET:
            field_dict["rule_name"] = rule_name
        if rule_parameters is not UNSET:
            field_dict["rule_parameters"] = rule_parameters
        if disabled is not UNSET:
            field_dict["disabled"] = disabled
        if configured is not UNSET:
            field_dict["configured"] = configured

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.field_model import FieldModel

        d = src_dict.copy()
        rule_name = d.pop("rule_name", UNSET)

        rule_parameters = []
        _rule_parameters = d.pop("rule_parameters", UNSET)
        for rule_parameters_item_data in _rule_parameters or []:
            rule_parameters_item = FieldModel.from_dict(rule_parameters_item_data)

            rule_parameters.append(rule_parameters_item)

        disabled = d.pop("disabled", UNSET)

        configured = d.pop("configured", UNSET)

        rule_parameters_model = cls(
            rule_name=rule_name,
            rule_parameters=rule_parameters,
            disabled=disabled,
            configured=configured,
        )

        rule_parameters_model.additional_properties = d
        return rule_parameters_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.compare_thresholds_model import CompareThresholdsModel


T = TypeVar("T", bound="ColumnComparisonModel")


@_attrs_define
class ColumnComparisonModel:
    """The column to column comparison model used to select which measures (min, max, sum, mean, null count, not nul count)
    are compared for this column between the compared (tested) column and the reference column from the reference table.

        Attributes:
            compared_column_name (Union[Unset, str]): The name of the compared column in the compared table (the tested
                table). The REST API returns all columns defined in the metadata.
            reference_column_name (Union[Unset, str]): The name of the reference column in the reference table (the source
                of truth). Set the name of the reference column to enable comparison between the compared and the reference
                columns.
            compare_min (Union[Unset, CompareThresholdsModel]): Model with the compare threshold levels for raising data
                quality issues at different severity levels when the difference between the compared (tested) table and the
                reference table (the source of truth) exceed given thresholds as a percentage of difference between the actual
                value and the expected value from the reference table.
            compare_max (Union[Unset, CompareThresholdsModel]): Model with the compare threshold levels for raising data
                quality issues at different severity levels when the difference between the compared (tested) table and the
                reference table (the source of truth) exceed given thresholds as a percentage of difference between the actual
                value and the expected value from the reference table.
            compare_sum (Union[Unset, CompareThresholdsModel]): Model with the compare threshold levels for raising data
                quality issues at different severity levels when the difference between the compared (tested) table and the
                reference table (the source of truth) exceed given thresholds as a percentage of difference between the actual
                value and the expected value from the reference table.
            compare_mean (Union[Unset, CompareThresholdsModel]): Model with the compare threshold levels for raising data
                quality issues at different severity levels when the difference between the compared (tested) table and the
                reference table (the source of truth) exceed given thresholds as a percentage of difference between the actual
                value and the expected value from the reference table.
            compare_null_count (Union[Unset, CompareThresholdsModel]): Model with the compare threshold levels for raising
                data quality issues at different severity levels when the difference between the compared (tested) table and the
                reference table (the source of truth) exceed given thresholds as a percentage of difference between the actual
                value and the expected value from the reference table.
            compare_not_null_count (Union[Unset, CompareThresholdsModel]): Model with the compare threshold levels for
                raising data quality issues at different severity levels when the difference between the compared (tested) table
                and the reference table (the source of truth) exceed given thresholds as a percentage of difference between the
                actual value and the expected value from the reference table.
    """

    compared_column_name: Union[Unset, str] = UNSET
    reference_column_name: Union[Unset, str] = UNSET
    compare_min: Union[Unset, "CompareThresholdsModel"] = UNSET
    compare_max: Union[Unset, "CompareThresholdsModel"] = UNSET
    compare_sum: Union[Unset, "CompareThresholdsModel"] = UNSET
    compare_mean: Union[Unset, "CompareThresholdsModel"] = UNSET
    compare_null_count: Union[Unset, "CompareThresholdsModel"] = UNSET
    compare_not_null_count: Union[Unset, "CompareThresholdsModel"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        compared_column_name = self.compared_column_name
        reference_column_name = self.reference_column_name
        compare_min: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.compare_min, Unset):
            compare_min = self.compare_min.to_dict()

        compare_max: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.compare_max, Unset):
            compare_max = self.compare_max.to_dict()

        compare_sum: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.compare_sum, Unset):
            compare_sum = self.compare_sum.to_dict()

        compare_mean: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.compare_mean, Unset):
            compare_mean = self.compare_mean.to_dict()

        compare_null_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.compare_null_count, Unset):
            compare_null_count = self.compare_null_count.to_dict()

        compare_not_null_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.compare_not_null_count, Unset):
            compare_not_null_count = self.compare_not_null_count.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if compared_column_name is not UNSET:
            field_dict["compared_column_name"] = compared_column_name
        if reference_column_name is not UNSET:
            field_dict["reference_column_name"] = reference_column_name
        if compare_min is not UNSET:
            field_dict["compare_min"] = compare_min
        if compare_max is not UNSET:
            field_dict["compare_max"] = compare_max
        if compare_sum is not UNSET:
            field_dict["compare_sum"] = compare_sum
        if compare_mean is not UNSET:
            field_dict["compare_mean"] = compare_mean
        if compare_null_count is not UNSET:
            field_dict["compare_null_count"] = compare_null_count
        if compare_not_null_count is not UNSET:
            field_dict["compare_not_null_count"] = compare_not_null_count

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.compare_thresholds_model import CompareThresholdsModel

        d = src_dict.copy()
        compared_column_name = d.pop("compared_column_name", UNSET)

        reference_column_name = d.pop("reference_column_name", UNSET)

        _compare_min = d.pop("compare_min", UNSET)
        compare_min: Union[Unset, CompareThresholdsModel]
        if isinstance(_compare_min, Unset):
            compare_min = UNSET
        else:
            compare_min = CompareThresholdsModel.from_dict(_compare_min)

        _compare_max = d.pop("compare_max", UNSET)
        compare_max: Union[Unset, CompareThresholdsModel]
        if isinstance(_compare_max, Unset):
            compare_max = UNSET
        else:
            compare_max = CompareThresholdsModel.from_dict(_compare_max)

        _compare_sum = d.pop("compare_sum", UNSET)
        compare_sum: Union[Unset, CompareThresholdsModel]
        if isinstance(_compare_sum, Unset):
            compare_sum = UNSET
        else:
            compare_sum = CompareThresholdsModel.from_dict(_compare_sum)

        _compare_mean = d.pop("compare_mean", UNSET)
        compare_mean: Union[Unset, CompareThresholdsModel]
        if isinstance(_compare_mean, Unset):
            compare_mean = UNSET
        else:
            compare_mean = CompareThresholdsModel.from_dict(_compare_mean)

        _compare_null_count = d.pop("compare_null_count", UNSET)
        compare_null_count: Union[Unset, CompareThresholdsModel]
        if isinstance(_compare_null_count, Unset):
            compare_null_count = UNSET
        else:
            compare_null_count = CompareThresholdsModel.from_dict(_compare_null_count)

        _compare_not_null_count = d.pop("compare_not_null_count", UNSET)
        compare_not_null_count: Union[Unset, CompareThresholdsModel]
        if isinstance(_compare_not_null_count, Unset):
            compare_not_null_count = UNSET
        else:
            compare_not_null_count = CompareThresholdsModel.from_dict(
                _compare_not_null_count
            )

        column_comparison_model = cls(
            compared_column_name=compared_column_name,
            reference_column_name=reference_column_name,
            compare_min=compare_min,
            compare_max=compare_max,
            compare_sum=compare_sum,
            compare_mean=compare_mean,
            compare_null_count=compare_null_count,
            compare_not_null_count=compare_not_null_count,
        )

        column_comparison_model.additional_properties = d
        return column_comparison_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class ConnectionTestStatus(str, Enum):
    CONNECTION_ALREADY_EXISTS = "CONNECTION_ALREADY_EXISTS"
    FAILURE = "FAILURE"
    SUCCESS = "SUCCESS"

    def __str__(self) -> str:
        return str(self.value)
